@@ -1,4 +1,4 @@
-/* $Id: document.cpp,v 1.12 2004/01/18 11:34:58 mueller Exp $ */
+/* $Id: document.cpp 371819 2004-12-19 04:28:15Z geiseri $ */
 /***************************************************************************
                           document.cpp  -  A DCOP Service to provide RSS data
                              -------------------
@@ -30,6 +30,7 @@ RSSDocument::RSSDocument(const QString& url) :
 	m_isLoading = false;
 	m_maxAge = 60;
 	m_Timeout = QDateTime::currentDateTime();
+	m_state.clear();
 }
 
 RSSDocument::~RSSDocument()
@@ -69,14 +70,19 @@ void RSSDocument::loadingComplete(Loader *ldr, Document doc, Status stat)
 		m_list.clear();
 		Article::List list = doc.articles();
 		for(Article::List::ConstIterator it = list.begin(); it != list.end(); ++it)
-			m_list.append( new RSSArticle(new Article(*it)));
+		{
+			int state = m_state[(*it).title()];
+			if( state == 0 ) m_state[(*it).title()] = 1; // new
+			else if( state == 1 ) m_state[(*it).title()] = 2; // old message now
+			m_list.append( new RSSArticle( new Article(*it)));
+		}
 		Image *img = m_Doc->image();
 		if ( img )
 		{
 			connect(img, SIGNAL(gotPixmap(const QPixmap &)),
 				SLOT(pixmapLoaded(const QPixmap &)));
 			img->getPixmap();
-			pixmapUpdateing(DCOPRef(this));
+			pixmapUpdating(DCOPRef(this));
 		}
 		m_isLoading = false;
 		documentUpdated(DCOPRef(this));
@@ -246,7 +252,7 @@ void RSSDocument::refresh()
 		Loader *loader = Loader::create(this,
 			SLOT(loadingComplete(Loader *, Document, Status)));
 		loader->loadFrom(KURL( m_Url ),  new FileRetriever());
-		documentUpdateing(DCOPRef(this));
+		documentUpdating(DCOPRef(this));
 	}
 	else
 	{
@@ -263,7 +269,7 @@ void RSSDocument::refresh()
 				connect(img, SIGNAL(gotPixmap(const QPixmap &)),
 					SLOT(pixmapLoaded(const QPixmap &)));
 				img->getPixmap();
-				pixmapUpdateing(DCOPRef(this));
+				pixmapUpdating(DCOPRef(this));
 			}
 		}
 		*/
@@ -283,5 +289,19 @@ void RSSDocument::setMaxAge(int _min)
 	m_Timeout.addSecs(m_maxAge);
 }
 
+int RSSDocument::state( const QString &title) const
+{
+	return m_state[title];
+}
+
+void RSSDocument::setState( const QString &title, int s )
+{
+	m_state[title] = s;
+}
+
+void RSSDocument::read( const QString &title)
+{
+	m_state[title] = 3;
+}
 
 #include "service.moc"
