@@ -2,7 +2,7 @@
 *                               dlgSystem.h
 *                             -------------------
 *
-*    Revision     : $Id: dlgSystem.h 252202 2003-09-18 18:46:39Z nhasan $
+*    Revision     : $Id: dlgSystem.h 476275 2005-11-01 01:30:58Z thiago $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -41,22 +41,11 @@ Q_OBJECT public:
     void applyData();
     void setData();
 
-private:
-
-    QString soundAdded;
-    QString soundStarted;
-    QString soundFinished;
-    QString soundFinishedAll;
-
 signals:
     void configChanged();
 
 protected slots:
     void slotChanged();
-
-private slots:
-    void setupSound();
-    void testSound();
 };
 
 #endif                          // _DLGSYSTEM_H
