@@ -2,7 +2,7 @@
 *                                droptarget.h
 *                             -------------------
 *
-*    Revision     : $Id: droptarget.h 395091 2005-03-05 17:30:10Z pino $
+*    Revision     : $Id: droptarget.h 476275 2005-11-01 01:30:58Z thiago $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -56,6 +56,7 @@ protected:
     /** No descriptions */
     virtual void mouseMoveEvent(QMouseEvent *);
     virtual void mousePressEvent(QMouseEvent * e);
+    virtual void mouseReleaseEvent(QMouseEvent *);
 
 private slots:
     void toggleSticky();
@@ -76,8 +77,11 @@ private:
     QBitmap mask;
 public:                      // Public attributes
     /**  */
-    int oldX;
-    int oldY;
+//    int oldX;
+//    int oldY;
+    int dx;
+    int dy;
+    bool isdragging;
 };
 
 #endif                          // _DROPTARGET_H
