@@ -2,7 +2,7 @@
 *                                  main.cpp
 *                             -------------------
 *
-*    Revision     : $Id: main.cpp 501833 2006-01-24 01:03:52Z ratz $
+*    Revision     : $Id: main.cpp 588225 2006-09-25 11:36:54Z pfeiffer $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *                 : Based On Caitoo v.0.7.3 (c) 1998 - 2000, Matej Koss
@@ -168,19 +168,19 @@ public:
         else if(args->count()>=2)
 		{
 			KURL::List urls;
-			QString dest;
 			for( int i=0; i < args->count(); ++i){
 				urls.append(KURL::fromPathOrURL( args->arg(i)));
 			}
 			
-			// Sometimes valid filenames are not recognised by KURL::isLocalFile(), they are marked as unvalid then
-			if ( args->count()==2 & ( urls.last().isLocalFile() | !urls.last().isValid()))
+			// Sometimes valid filenames are not recognised by KURL::isLocalFile(), they are marked as invalid then
+			if ( args->count()==2 && ( urls.last().isLocalFile() || !urls.last().isValid()))
 			{
-				dest=urls.last().path();
-				kmain->addTransferEx( urls.first(), dest );
+				kmain->addTransferEx( urls.first(), urls.last() );
 			}
 			else
-				kmain->addTransfers( urls, dest );
+			{
+				kmain->addTransfers( urls, QString() );
+			}
 		}
         args->clear();
 
