@@ -2,7 +2,7 @@
 *                                slaveevent.h
 *                             -------------------
 *
-*    Revision     : $Id: slaveevent.h 162135 2002-06-20 10:20:24Z charbonnier $
+*    Revision     : $Id: slaveevent.h 530904 2006-04-18 00:26:19Z rohanpm $
 *    begin        : Tue Jan 29 2002
 *    copyright    : (C) 2002 by Patrick Charbonnier
 *    email        :pch@freeshell.org
@@ -38,20 +38,20 @@ class Transfer;
 class SlaveEvent:public QCustomEvent
 {
 public:
-    SlaveEvent(Transfer * _item, unsigned int _event, unsigned long _ldata = 0L);
+    SlaveEvent(Transfer * _item, unsigned int _event, Q_ULLONG _ldata = 0L);
     SlaveEvent(Transfer * _item, unsigned int _event, const QString & _msg);
     ~SlaveEvent();
 
     unsigned int getEvent() const;
     Transfer *getItem() const;
-    unsigned long getData() const;
+    Q_ULLONG getData() const;
     const QString & getMsg() const;
 
 
 private:
     unsigned int m_event;
     Transfer *m_item;
-    unsigned long m_ldata;
+    Q_ULLONG m_ldata;
     QString m_msg;
 
 };
