@@ -36,7 +36,7 @@ class QDomDocument;
 class KProcess;
 class KURL;
 
-class Article : public XMLNewsArticle, public KShared
+class KDE_EXPORT Article : public XMLNewsArticle, public KShared
 {
 	public:
 		typedef KSharedPtr<Article> Ptr;
@@ -58,7 +58,7 @@ class Article : public XMLNewsArticle, public KShared
 		bool m_read;
 };
 
-class NewsSourceBase : public XMLNewsSource, public KShared
+class KDE_EXPORT NewsSourceBase : public XMLNewsSource, public KShared
 {
 	Q_OBJECT
 
@@ -132,7 +132,7 @@ class NewsSourceBase : public XMLNewsSource, public KShared
 		Article::List m_articles;
 };
 
-class SourceFileNewsSource : public NewsSourceBase
+class KDE_EXPORT SourceFileNewsSource : public NewsSourceBase
 {
 	Q_OBJECT
 	
@@ -170,7 +170,7 @@ class SourceFileNewsSource : public NewsSourceBase
 #undef EHOSTDOWN
 #undef EHOSTUNREACH
 
-class ProgramNewsSource : public NewsSourceBase
+class KDE_EXPORT ProgramNewsSource : public NewsSourceBase
 {
 	Q_OBJECT
 	
