@@ -57,7 +57,6 @@ class KNewsTicker : public KPanelApplet, virtual public ConfigIface,
 		virtual uint mouseWheelSpeed() const { return m_cfg->mouseWheelSpeed(); }
 		virtual uint scrollingDirection() const { return m_cfg->scrollingDirection(); }
 		virtual bool customNames() const { return m_cfg->customNames(); }
-		virtual bool endlessScrolling() const { return m_cfg->endlessScrolling(); }
 		virtual bool scrollMostRecentOnly() const { return m_cfg->scrollMostRecentOnly(); }
 		virtual bool offlineMode() const { return m_cfg->offlineMode(); }
 		virtual bool underlineHighlighted() const { return m_cfg->underlineHighlighted(); }
@@ -72,7 +71,6 @@ class KNewsTicker : public KPanelApplet, virtual public ConfigIface,
 		virtual void setMouseWheelSpeed(const uint);
 		virtual void setScrollingDirection(const uint);
 		virtual void setCustomNames(bool);
-		virtual void setEndlessScrolling(bool);
 		virtual void setScrollMostRecentOnly(bool);
 		virtual void setOfflineMode(bool);
 		virtual void setUnderlineHighlighted(bool);
@@ -93,8 +91,7 @@ class KNewsTicker : public KPanelApplet, virtual public ConfigIface,
 		virtual void help();
 		virtual void reportBug();
 		virtual void mousePressEvent(QMouseEvent *);
-		virtual void orientationChange(Orientation);
-		virtual void popupDirectionChange(KPanelApplet::Direction);
+		virtual void positionChange(Position);
 
 	protected slots:
 		void slotArrowButtonPressed();
@@ -102,7 +99,6 @@ class KNewsTicker : public KPanelApplet, virtual public ConfigIface,
 		void slotNewsSourceFailed(const NewsSourceBase::Ptr &);
 		void slotContextMenuAboutToHide();
 		void slotNotifyOfFailures();
-		void slotKillContextMenu();
 
 	private:
 		void setupArrowButton();
@@ -129,11 +125,22 @@ class KNewsTickerMenu : public KPopupMenu
 
 	public:
 		KNewsTickerMenu(KNewsTicker *, const char * = 0);
-		virtual int exec(const QPoint &, int = 0);
-	
+		void setFullMenu(bool full) { m_fullMenu = full; populateMenu(); }
+
+	protected slots:
+		void populateMenu();
+
+	private slots:
+		void slotShowHelp();
+		void slotShowAbout();
+		void slotConfigure();
+		void slotToggleOfflineMode();
+		void slotCheckNews(int idx);
+		void slotOpenArticle(int idx);
+
 	private:
-		unsigned int m_idx;
 		KNewsTicker *m_parent;
+		bool m_fullMenu;
 };
 
 #endif // KNEWSTICKER_H
