@@ -129,7 +129,7 @@ private:
 };
 
 NewsScroller::NewsScroller(QWidget *parent, ConfigAccess *cfg, const char *name)
-	: QFrame(parent, name),
+	: QFrame(parent, name, WNoAutoErase),
 	m_cfg(cfg),
 	m_scrollTimer(new QTimer(this)),
 	m_activeHeadline(0),
@@ -183,9 +183,8 @@ void NewsScroller::dropEvent(QDropEvent* event)
 		// </HACK>
 		newSourceUrl = newSourceUrl.stripWhiteSpace();
 		if (!isHeadline(newSourceUrl) && KMessageBox::questionYesNo(this, i18n("<p>Do you really want to add '%1' to"
-				" the list of news sources?</p><p>Press 'Yes' to add the news source to"
-				" the list, press 'No' to cancel and close this dialog.</p>")
-					.arg(newSourceUrl)) == KMessageBox::Yes) {
+				" the list of news sources?</p>")
+					.arg(newSourceUrl), QString::null, i18n("Add"), KStdGuiItem::cancel()) == KMessageBox::Yes) {
 			KConfig cfg(QString::fromLatin1("knewsticker_panelappletrc"), false, false);
 			ConfigAccess configFrontend(&cfg);
 			QStringList newsSources = configFrontend.newsSources();
@@ -259,8 +258,8 @@ void NewsScroller::scroll(int distance, bool interpret_directions)
 	
 	if (contentsRect().contains(pt))
 		updateActive(pt);
-	
-	repaint(false);
+
+	update();
 }
 
 void NewsScroller::enterEvent(QEvent *)
@@ -338,7 +337,7 @@ void NewsScroller::mouseMoveEvent(QMouseEvent *e)
 	}
 
 	if (updateActive(e->pos()))
-		repaint(false);
+		update();
 }
 
 void NewsScroller::wheelEvent(QWheelEvent *e)
@@ -361,7 +360,7 @@ void NewsScroller::leaveEvent(QEvent *)
 
 	if (m_activeHeadline) {
 		m_activeHeadline = 0;
-		repaint(false);
+		update();
 	}
 }
 
@@ -489,7 +488,7 @@ void NewsScroller::reset(bool bSeparatorOnly)
 			m_offset = - scrollHeight();
 	}
 
-	repaint(false);
+	update();
 }
 
 int NewsScroller::scrollWidth() const
