@@ -83,7 +83,7 @@ public:
 	/**
 	 * Returns the number of chat views attached to this window
 	 */
-	const int chatViewCount() { return chatViewList.count(); }
+	int chatViewCount() { return chatViewList.count(); }
 
 	/**
 	 * Returns the chatview in the currently active tab, or the only chat view
@@ -94,8 +94,8 @@ public:
 	void updateMembersActions();
 	void setStatus( const QString & );
 
-	/** 
-	 * Reimplemented from KMainWindow - asks each ChatView in the window if it is ok to close the window 
+	/**
+	 * Reimplemented from KMainWindow - asks each ChatView in the window if it is ok to close the window
 	 * @return true if no ChatView objects to closing.
 	 */
 	virtual bool queryClose();
@@ -105,7 +105,7 @@ public:
 	QPtrList<ChatView> chatViewList;
 
 private:
-	// All KopeteChatWindows are created by the findWindow function
+	// All KopeteChatWindows are created by the window function
 	KopeteChatWindow( QWidget *parent = 0, const char* name = "KopeteChatWindow" );
 
 	/**
@@ -211,6 +211,7 @@ private slots:
 
 	void toggleAutoSpellChecking();
 	void slotRTFEnabled( ChatView*, bool );
+	void slotAutoSpellCheckEnabled( ChatView*, bool );
 
 	void slotSetCaption( bool );
 	void slotUpdateCaptionIcons( ChatView * );
