@@ -2,7 +2,7 @@
     kopetemessage.cpp  -  Base class for Kopete messages
 
     Copyright (c) 2002-2003 by Martijn Klingens       <klingens@kde.org>
-    Copyright (c) 2002-2005 by Olivier Goffart        <ogoffart @ kde.org>
+    Copyright (c) 2002-2006 by Olivier Goffart        <ogoffart @ kde.org>
 
     Kopete    (c) 2002-2005 by the Kopete developers  <kopete-devel@kde.org>
 
@@ -29,6 +29,7 @@
 #include <kiconloader.h>
 #include <kstringhandler.h>
 #include <kmdcodec.h>
+#include <qguardedptr.h>
 
 #include "kopetemessage.h"
 #include "kopetemetacontact.h"
@@ -46,10 +47,10 @@ class Message::Private
 {
 public:
 	Private( const QDateTime &timeStamp, const Contact *from, const ContactPtrList &to,
-	         const QString &body, const QString &subject, MessageDirection direction, MessageFormat f,
+	         const QString &subject, MessageDirection direction,
 	         const QString &requestedPlugin, MessageType type );
 
-	const Contact *from;
+	QGuardedPtr<const Contact> from;
 	ContactPtrList to;
 	ChatSession *manager;
 
@@ -61,6 +62,7 @@ public:
 	bool bgOverride;
 	bool fgOverride;
 	bool rtfOverride;
+	bool isRightToLeft;
 	QDateTime timeStamp;
 	QFont font;
 
@@ -68,52 +70,29 @@ public:
 	QColor bgColor;
 	QString body;
 	QString subject;
-	
-	//the cache is used to keep the base64 if images
-	//Note: in QT4 this should be probably a QHash
-	static QMap <QString , QString> imageCache;
-
 };
 
-QMap <QString , QString> Message::Private::imageCache;
-
 Message::Private::Private( const QDateTime &timeStamp, const Contact *from,
-             const ContactPtrList &to, const QString &body, const QString &subject,
-				 MessageDirection direction, MessageFormat f, const QString &requestedPlugin, MessageType type )
-	: from(from), to(to), manager(0), direction(direction), format(f), type(type)
-	, requestedPlugin(requestedPlugin), importance( (to.count() <= 1) ? Normal : Low ), bgOverride(false), fgOverride(false)
-	, rtfOverride(false), timeStamp(timeStamp), body(body), subject(subject)
+		const ContactPtrList &to, const QString &subject,
+		MessageDirection direction, const QString &requestedPlugin, MessageType type )
+: from( from ), to( to ), manager( 0 ), direction( direction ), format( PlainText ), type( type ),
+	requestedPlugin( requestedPlugin ), importance( (to.count() <= 1) ? Normal : Low ),
+	bgOverride( false ), fgOverride( false ), rtfOverride( false ), isRightToLeft( false ),
+	timeStamp( timeStamp ), body( QString::null ), subject( subject )
 {
-	if( format == RichText )
-	{
-		//This is coming from the RichTextEditor component.
-		//Strip off the containing HTML document
-		this->body.replace( QRegExp( QString::fromLatin1(".*<body.*>\\s+(.*)\\s+</body>.*") ), QString::fromLatin1("\\1") );
-
-		//Strip <p> tags
-		this->body.replace( QString::fromLatin1("<p>"), QString::null );
-
-		//Replace </p> with a <br/>
-		this->body.replace( QString::fromLatin1("</p>") , QString::fromLatin1("<br/>") );
-
-		//Remove trailing <br/>
-		if ( this->body.endsWith( QString::fromLatin1("<br/>") ) )
-			this->body.truncate( this->body.length() - 5 );
-		this->body.remove(  QString::fromLatin1("\n") );
-	}
 }
 
-
 Message::Message()
-    : d( new Private( QDateTime::currentDateTime(), 0L, QPtrList<Contact>(), QString::null, QString::null, Internal,
-	PlainText, QString::null, TypeNormal ) )
+: d( new Private( QDateTime::currentDateTime(), 0L, QPtrList<Contact>(), QString::null, Internal,
+	QString::null, TypeNormal ) )
 {
 }
 
 Message::Message( const Contact *fromKC, const QPtrList<Contact> &toKC, const QString &body,
 		  MessageDirection direction, MessageFormat f, const QString &requestedPlugin, MessageType type )
-    : d( new Private( QDateTime::currentDateTime(), fromKC, toKC, body, QString::null, direction, f, requestedPlugin, type ) )
+: d( new Private( QDateTime::currentDateTime(), fromKC, toKC, QString::null, direction, requestedPlugin, type ) )
 {
+	doSetBody( body, f );
 }
 
 Message::Message( const Contact *fromKC, const Contact *toKC, const QString &body,
@@ -121,26 +100,30 @@ Message::Message( const Contact *fromKC, const Contact *toKC, const QString &bod
 {
 	QPtrList<Contact> to;
 	to.append(toKC);
-	d = new Private( QDateTime::currentDateTime(), fromKC, to, body, QString::null, direction, f, requestedPlugin, type );
+	d = new Private( QDateTime::currentDateTime(), fromKC, to, QString::null, direction, requestedPlugin, type );
+	doSetBody( body, f );
 }
 
 Message::Message( const Contact *fromKC, const QPtrList<Contact> &toKC, const QString &body,
 		  const QString &subject, MessageDirection direction, MessageFormat f, const QString &requestedPlugin, MessageType type )
-    : d( new Private( QDateTime::currentDateTime(), fromKC, toKC, body, subject, direction, f, requestedPlugin, type ) )
+    : d( new Private( QDateTime::currentDateTime(), fromKC, toKC, subject, direction, requestedPlugin, type ) )
 {
+	doSetBody( body, f );
 }
 
 Message::Message( const QDateTime &timeStamp, const Contact *fromKC, const QPtrList<Contact> &toKC,
 		  const QString &body, MessageDirection direction, MessageFormat f, const QString &requestedPlugin, MessageType type )
-    : d( new Private( timeStamp, fromKC, toKC, body, QString::null, direction, f, requestedPlugin, type ) )
+    : d( new Private( timeStamp, fromKC, toKC, QString::null, direction, requestedPlugin, type ) )
 {
+	doSetBody( body, f );
 }
 
 
 Message::Message( const QDateTime &timeStamp, const Contact *fromKC, const QPtrList<Contact> &toKC,
 		  const QString &body, const QString &subject, MessageDirection direction, MessageFormat f, const QString &requestedPlugin, MessageType type )
-    : d( new Private( timeStamp, fromKC, toKC, body, subject, direction, f, requestedPlugin, type ) )
+    : d( new Private( timeStamp, fromKC, toKC, subject, direction, requestedPlugin, type ) )
 {
+	doSetBody( body, f );
 }
 
 Kopete::Message::Message( const Message &other )
@@ -207,32 +190,55 @@ void Message::setFont( const QFont &font )
 	d->font = font;
 }
 
-void Message::setBody( const QString &body, MessageFormat f )
+void Message::doSetBody( const QString &_body, Message::MessageFormat f )
 {
-	detach();
+	QString body = _body;
 
-	QString theBody = body;
+	//TODO: move that in ChatTextEditPart::contents
 	if( f == RichText )
 	{
 		//This is coming from the RichTextEditor component.
 		//Strip off the containing HTML document
-		theBody.replace( QRegExp( QString::fromLatin1(".*<body.*>\\s+(.*)\\s+</body>.*") ), QString::fromLatin1("\\1") );
+		body.replace( QRegExp( QString::fromLatin1(".*<body[^>]*>(.*)</body>.*") ), QString::fromLatin1("\\1") );
 
 		//Strip <p> tags
-		theBody.replace( QString::fromLatin1("<p>"), QString::null );
+		body.replace( QString::fromLatin1("<p>"), QString::null );
 
 		//Replace </p> with a <br/>
-		theBody.replace( QString::fromLatin1("</p>"), QString::fromLatin1("<br/>") );
+		body.replace( QString::fromLatin1("</p>"), QString::fromLatin1("<br/>") );
 
 		//Remove trailing </br>
-		if ( theBody.endsWith( QString::fromLatin1("<br/>") ) )
-			theBody.truncate( theBody.length() - 5 );
-
-		theBody.remove( QString::fromLatin1("\n") );
+		if ( body.endsWith( QString::fromLatin1("<br/>") ) )
+			body.truncate( body.length() - 5 );
+	
+		body.remove( QString::fromLatin1("\n") );
+		body.replace( QRegExp( QString::fromLatin1( "\\s\\s" ) ), QString::fromLatin1( " &nbsp;" ) );
 	}
+	/*
+	else if( f == ParsedHTML )
+	{
+		kdWarning( 14000 ) << k_funcinfo << "using ParsedHTML which is internal! Message: '" <<
+			body << "', Backtrace: " << kdBacktrace() << endl;
+	}
+	*/
 
-	d->body=theBody;
+	d->body = body;
 	d->format = f;
+
+	// unescaping is very expensive, do it only once and cache the result
+	d->isRightToLeft = ( f & RichText ? unescape( d->body ).isRightToLeft() : d->body.isRightToLeft() );
+}
+
+void Message::setBody( const QString &body, MessageFormat f )
+{
+	detach();
+
+	doSetBody( body, f );
+}
+
+bool Message::isRightToLeft() const
+{
+	return d->isRightToLeft;
 }
 
 void Message::setImportance(Message::MessageImportance i)
@@ -245,20 +251,63 @@ QString Message::unescape( const QString &xml )
 {
 	QString data = xml;
 
-	//remove linebreak and multiple spaces
-	data.replace( QRegExp( QString::fromLatin1( "\\s*[\n\r\t]+\\s*" ) , false ), QString::fromLatin1(" " )) ;
+	// Remove linebreak and multiple spaces. First return nbsp's to normal spaces :)
+	data.simplifyWhiteSpace();
 
-	data.replace( QRegExp( QString::fromLatin1( "< *img[^>]*title=\"([^>\"]*)\"[^>]*>" ) , false ), QString::fromLatin1( "\\1" ) );  //escape smeleys, return to the original code
-	data.replace( QRegExp( QString::fromLatin1( "< */ *p[^>]*>" ) , false ), QString::fromLatin1( "\n" ) );
-	data.replace( QRegExp( QString::fromLatin1( "< */ *div[^>]*>" ) , false ), QString::fromLatin1( "\n" ) );
-	data.replace( QRegExp( QString::fromLatin1( "< *br */? *>" ) , false ), QString::fromLatin1( "\n" ) );
-	data.replace( QRegExp( QString::fromLatin1( "<[^>]*>" ) ), QString::null );
+	int pos;
+	while ( ( pos = data.find( '<' ) ) != -1 )
+	{
+		int endPos = data.find( '>', pos + 1 );
+		if( endPos == -1 )
+			break;    // No more complete elements left
 
+		// Take the part between < and >, and extract the element name from that
+		int matchWidth = endPos - pos + 1;
+		QString match = data.mid( pos + 1, matchWidth - 2 ).simplifyWhiteSpace();
+		int elemEndPos = match.find( ' ' );
+		QString elem = ( elemEndPos == -1 ? match.lower() : match.left( elemEndPos ).lower() );
+		if ( elem == QString::fromLatin1( "img" ) )
+		{
+			// Replace smileys with their original text'
+			const QString attrTitle  = QString::fromLatin1( "title=\"" );
+			int titlePos    = match.find( attrTitle, elemEndPos );
+			int titleEndPos = match.find( '"',       titlePos + attrTitle.length() );
+			if( titlePos == -1 || titleEndPos == -1 )
+			{
+				// Not a smiley but a normal <img>
+				// Don't update pos, we restart at this position :)
+				data.remove( pos, matchWidth );
+			}
+			else
+			{
+				QString orig = match.mid( titlePos + attrTitle.length(),
+					titleEndPos - titlePos - attrTitle.length() );
+				data.replace( pos, matchWidth, orig );
+				pos += orig.length();
+			}
+		}
+		else if ( elem == QString::fromLatin1( "/p" ) || elem == QString::fromLatin1( "/div" ) ||
+			elem == QString::fromLatin1( "br" ) )
+		{
+			// Replace paragraph, div and line breaks with a newline
+			data.replace( pos, matchWidth, '\n' );
+			pos++;
+		}
+		else
+		{
+			// Remove all other elements entirely
+			// Don't update pos, we restart at this position :)
+			data.remove( pos, matchWidth );
+		}
+	}
+
+	// Replace stuff starting with '&'
 	data.replace( QString::fromLatin1( "&gt;" ), QString::fromLatin1( ">" ) );
 	data.replace( QString::fromLatin1( "&lt;" ), QString::fromLatin1( "<" ) );
 	data.replace( QString::fromLatin1( "&quot;" ), QString::fromLatin1( "\"" ) );
 	data.replace( QString::fromLatin1( "&nbsp;" ), QString::fromLatin1( " " ) );
 	data.replace( QString::fromLatin1( "&amp;" ), QString::fromLatin1( "&" ) );
+	data.replace( QString::fromLatin1( "&#160;" ), QString::fromLatin1( " " ) );  //this one is used in jabber:  note, we should escape all &#xx;
 
 	return data;
 }
@@ -293,11 +342,17 @@ QString Message::plainBody() const
 QString Message::escapedBody() const
 {
 	QString escapedBody=d->body;
+//	kdDebug(14000) << k_funcinfo << escapedBody << " " << d->rtfOverride << endl;
 
 	if( d->format & PlainText )
 	{
 		escapedBody=escape( escapedBody );
 	}
+	else if( d->format & RichText && d->rtfOverride)
+	{
+		//remove the rich text
+		escapedBody = escape (unescape( escapedBody ) );
+	}
 
 	return escapedBody;
 }
@@ -312,7 +367,7 @@ QString Message::parsedBody() const
 	}
 	else
 	{
-		return Kopete::Emoticons::parseEmoticons(parseLinks(escapedBody(), d->format));
+		return Kopete::Emoticons::parseEmoticons(parseLinks(escapedBody(), RichText));
 	}
 }
 
@@ -467,210 +522,23 @@ void Message::setManager(ChatSession *kmm)
 	d->manager=kmm;
 }
 
-
-QDomElement Message::contactNode( QDomDocument doc, const Contact *contact )
+QString Message::getHtmlStyleAttribute() const
 {
-	KopetePrefs *p = KopetePrefs::prefs();
-
-	// These colors are used for coloring nicknames. I tried to use
-	// colors both visible on light and dark background.
-	static const char* const nameColors[] =
-	{
-		"red", "blue" , "gray", "magenta", "violet", "olive", "yellowgreen",
-		"darkred", "darkgreen", "darksalmon", "darkcyan", "darkyellow",
-		"mediumpurple", "peru", "olivedrab", "royalred", "darkorange", "slateblue",
-		"slategray", "goldenrod", "orangered", "tomato", "dogderblue", "steelblue",
-		"deeppink", "saddlebrown", "coral", "royalblue"
-	};
-
-	static const int nameColorsLen = sizeof(nameColors) / sizeof(nameColors[0]) - 1;
+	QString styleAttribute;
 	
-	QString contactName = contact->property(Global::Properties::self()->nickName()).value().toString();
-	if( p->truncateContactNames() )
-	{
-		contactName = KStringHandler::csqueeze( contactName, p->maxContactNameLength() );
-	}
-
-	if(contactName.isEmpty())
-		contactName = contact->metaContact() ? contact->metaContact()->displayName() : contact->contactId();
-
-	QString metacontactName = contact->metaContact() ? contact->metaContact()->displayName() : contactName;
-	QDomElement contactNode = doc.createElement( QString::fromLatin1("contact") );
-	contactNode.setAttribute( QString::fromLatin1("contactId"), contact->contactId() );
-
-	QDomElement contactNameNode = doc.createElement( QString::fromLatin1("contactDisplayName") );
-	contactNameNode.setAttribute( QString::fromLatin1("dir"), contactName.isRightToLeft() ?
-	                              QString::fromLatin1("rtl") : QString::fromLatin1("ltr") );
-	contactNameNode.setAttribute( QString::fromLatin1("text"), QStyleSheet::escape( contactName ) );
-	contactNode.appendChild( contactNameNode );
-
-
-	QDomElement metacontactNameNode = doc.createElement( QString::fromLatin1("metaContactDisplayName") );
-	metacontactNameNode.setAttribute( QString::fromLatin1("dir"), metacontactName.isRightToLeft() ?
-	                                  QString::fromLatin1("rtl") : QString::fromLatin1("ltr") );
-	metacontactNameNode.setAttribute( QString::fromLatin1("text"), QStyleSheet::escape( metacontactName ) );
-
-	
-	if( contact->metaContact() && !contact->metaContact()->metaContactId().isEmpty())
-	{
-		if(d->imageCache.contains(contact->metaContact()->metaContactId()))
-		{
-			contactNode.setAttribute( QString::fromLatin1("userPhoto"), d->imageCache[contact->metaContact()->metaContactId()]);
-		}
-		else
-		{
-			QImage photo = contact->metaContact()->photo();
-			if( !photo.isNull() )
-			{
-				QByteArray ba;
-				QBuffer buffer( ba );
-				buffer.open( IO_WriteOnly );
-				photo.save ( &buffer, "PNG" );
-				QString photo64=KCodecs::base64Encode(ba);
-			
-				if(d->imageCache.count() > 14)
-				{
-					d->imageCache.clear();
-				}
-				d->imageCache.insert(contact->metaContact()->metaContactId(), photo64);
-				
-				contactNode.setAttribute( QString::fromLatin1("userPhoto"), photo64 );
-			}
-		}
-	}
-
-	contactNode.appendChild( metacontactNameNode );
-
-	// protocol() returns NULL here in the style preview in appearance config.
-	// this isn't the right place to work around it, since contacts should never have
-	// no protocol, but it works for now.
-	QString iconName = QString::fromLatin1("kopete");
-	if ( Protocol *protocol = contact->protocol() )
-		iconName = protocol->pluginIcon();
-
-	QString iconPath = KGlobal::iconLoader()->iconPath( iconName, KIcon::Small );
-	contactNode.setAttribute( QString::fromLatin1("protocolIcon"), iconPath );
-
-	// hash contactId to deterministically pick a color for the contact
-	int hash = 0;
-	const QString &contactId = contact->contactId();
-	for( uint f = 0; f < contactId.length(); ++f )
-		hash += contactId[f].unicode() * f;
-
-	QString color = QColor( nameColors[ hash % nameColorsLen ] ).name();
-	contactNode.setAttribute( QString::fromLatin1("color"), color );
-
-	return contactNode;
-}
-
-
-const QDomDocument Message::asXML()
-{
-	QDomDocument doc;
-	QDomElement messageNode = doc.createElement( QString::fromLatin1("message") );
-	messageNode.setAttribute( QString::fromLatin1("time"),
-		KGlobal::locale()->formatTime(d->timeStamp.time(), true) );
-	messageNode.setAttribute( QString::fromLatin1("timestamp"),
-		KGlobal::locale()->formatDateTime(d->timeStamp) );
-	if( d->timeStamp.date() == QDate::currentDate() )
-	{
-		messageNode.setAttribute( QString::fromLatin1("formattedTimestamp"),
-			KGlobal::locale()->formatTime(d->timeStamp.time(), true) );
-	}
-	else
-	{
-		messageNode.setAttribute( QString::fromLatin1("formattedTimestamp"),
-			KGlobal::locale()->formatDateTime(d->timeStamp) );
-	}
-	messageNode.setAttribute( QString::fromLatin1("subject"), QStyleSheet::escape( d->subject ) );
-
-	/**
-	 * @deprecated backwards-compatibility direction attribute for old XSLT
-	 * It used to be the case that Action was in the MessageDirection enum.
-	 * Clearly this is broken - Action is not a direction, and it was impossible
-	 * to tell whether actions were incoming or outgoing. Anyway, some XSLT view
-	 * styles were written back when this was the case. They expected numeric
-	 * 'directions'. So we fake some for them.
-	 */
-	{
-		int oldDirection = 0;
-		if( type() == TypeAction )
-			oldDirection = 3;
-		else if( direction() == Inbound )
-			oldDirection = 0;
-		else if( direction() == Outbound )
-			oldDirection = 1;
-		else if( direction() == Internal )
-			oldDirection = 2;
-		messageNode.setAttribute( QString::fromLatin1("direction"), oldDirection );
-	}
-
-	const char *route;
-	switch( d->direction )
-	{
-		case Inbound:
-			route = "inbound";
-			break;
-		case Outbound:
-			route = "outbound";
-			break;
-		case Internal:
-			route = "internal";
-			break;
-		default:
-			kdWarning(14000) << k_funcinfo << "unknown message direction " << d->direction << endl;
-			route = "unknown";
-			break;
-	}
-	messageNode.setAttribute( QString::fromLatin1("route"), QString::fromLatin1(route) );
-
-	const char *type;
-	switch( d->type )
-	{
-		case TypeNormal:
-			type = "normal";
-			break;
-		case TypeAction:
-			type = "action";
-			break;
-		default:
-			kdWarning(14000) << k_funcinfo << "unknown message type " << d->type << endl;
-			type = "unknown";
-			break;
-	}
-	messageNode.setAttribute( QString::fromLatin1("type"), QString::fromLatin1(type) );
-
-	messageNode.setAttribute( QString::fromLatin1("importance"), d->importance );
-
-
-	//build the <from> and <to>  node
-	if( const Contact *mainContact = (d->direction == Inbound ? d->from : d->to.getFirst()) )
-		messageNode.setAttribute( QString::fromLatin1("mainContactId"), mainContact->contactId() );
-
-	doc.appendChild( messageNode );
-
-	if( const Contact *c = d->from )
-	{
-		kdDebug() << "KopeteMessage::asXML ** from " << c->contactId() << endl;
-		QDomElement fromNode = doc.createElement( QString::fromLatin1("from") );
-		fromNode.appendChild( contactNode( doc, c ) );
-		messageNode.appendChild( fromNode );
-	}
-
-	if( const Contact *c = d->to.getFirst() )
-	{
-		QDomElement toNode = doc.createElement( QString::fromLatin1("to") );
-		toNode.appendChild( contactNode( doc, c ) );
-		messageNode.appendChild( toNode );
-	}
-
-	QDomElement bodyNode = doc.createElement( QString::fromLatin1("body") );
+	styleAttribute = QString::fromUtf8("style=\"");
 
+	// Affect foreground(color) and background color to message.
 	if( !d->fgOverride && d->fgColor.isValid() )
-		bodyNode.setAttribute( QString::fromLatin1("color"), d->fgColor.name() );
+	{
+		styleAttribute += QString::fromUtf8("color: %1; ").arg(d->fgColor.name());
+	}
 	if( !d->bgOverride && d->bgColor.isValid() )
-		bodyNode.setAttribute( QString::fromLatin1("bgcolor"), d->bgColor.name() );
-
+	{
+		styleAttribute += QString::fromUtf8("background-color: %1; ").arg(d->bgColor.name());
+	}
+	
+	// Affect font parameters.
 	if( !d->rtfOverride && d->font!=QFont() )
 	{
 		QString fontstr;
@@ -685,17 +553,12 @@ const QDomDocument Message::asXML()
 		if(d->font.bold())
 			fontstr+=QString::fromLatin1("font-weight: bold;");
 
-		bodyNode.setAttribute( QString::fromLatin1("font"), fontstr );
+		styleAttribute += fontstr;
 	}
 
-	bodyNode.setAttribute( QString::fromLatin1("dir"),
-		plainBody().isRightToLeft() ? QString::fromLatin1("rtl") : QString::fromLatin1("ltr") );
-	QDomCDATASection bodyText = doc.createCDATASection( parsedBody() );
-	bodyNode.appendChild( bodyText );
+	styleAttribute += QString::fromUtf8("\"");
 
-	messageNode.appendChild( bodyNode );
-
-	return doc;
+	return styleAttribute;
 }
 
 // KDE4: Move that to a utils class/namespace
@@ -776,9 +639,3 @@ QString Message::decodeString( const QCString &message, const QTextCodec *provid
 
 	return result;
 }
-
-void Kopete::Message::clearImageCache()  //[static]
-{
-	Private::imageCache.clear();
-}
-
