@@ -41,6 +41,7 @@ namespace Kopete {
 
 class Plugin;
 class Group;
+class Picture;
 
 /**
  * @author Will Stephenson <will@stevello.free-online.co.uk>
@@ -186,6 +187,15 @@ public:
 	 */
 	QImage photo() const;
 
+	/**
+	 * Return the correct Kopete::Picture object depending of the metacontact photo source.
+	 *
+	 * This photo is obtained from the source set with @ref setPhotoSource
+	 *
+	 * KDE4 TODO: Rename this to photo() and use the new object.
+	 */
+	Picture &picture() const;
+
 	/**
 	 * @brief Set the custom displayName.
 	 *
@@ -207,10 +217,10 @@ public:
 	QString customDisplayName() const;
 
 	/**
-	 * @brief Returns the custom display name
+	 * @brief Returns the custom display photo
 	 *
-	 * @see displayName()
-	 * @see displayNameSource()
+	 * @see photo()
+	 * @see photoSource()
 	 */
 	KURL customPhoto() const;
 
@@ -441,7 +451,7 @@ public slots:
 	 * @brief Set if this is a temporary contact. (see @ref isTemporary)
 	 *
 	 * @param b if the contact is or not temporary
-	 * @param group if the contact was temporary and b is true, then the contact will be moved to this group.
+	 * @param group if the contact was temporary and b is false, then the contact will be moved to this group.
 	 *  if group is null, it will be moved to top-level
 	 */
 	void setTemporary( bool b = true, Kopete::Group *group = 0L );
@@ -571,6 +581,11 @@ private slots:
 	 */
 	void slotAllPluginsLoaded();
 
+	/**
+	 * Update the KABC Picture when the addressbook is changed.
+	 */
+	void slotUpdateAddressBookPicture();
+
 protected:
 	//QImage photoFromContact( Kopete::Contact *c) const;
 	//QImage photoFromKABC( const QString &id ) const;
