@@ -16,6 +16,7 @@
 
 #include <qfile.h>
 #include <qdict.h>
+#include <qtimer.h>
 
 #include <kgenericfactory.h>
 #include <kaboutdata.h>
@@ -70,6 +71,13 @@ StatisticsPlugin::StatisticsPlugin( QObject *parent, const char *name, const QSt
 
 	setXMLFile("statisticsui.rc");
 
+	/* Initialization reads the database, so it could be a bit time-consuming
+	due to disk access. This should overcome the problem and makes it non-blocking. */
+	QTimer::singleShot(0, this, SLOT(slotInitialize()));
+}	
+
+void StatisticsPlugin::slotInitialize()
+{
 	// Initializes the database
 	m_db = new StatisticsDB();
 	
@@ -79,7 +87,7 @@ StatisticsPlugin::StatisticsPlugin( QObject *parent, const char *name, const QSt
 	{
 		slotMetaContactAdded(it.current());
 	}
-}	
+}
 
 StatisticsPlugin::~StatisticsPlugin()
 {
