@@ -36,18 +36,18 @@
 
 class KAction;
 class GaduAccount;
-class KopeteAccount;
-class KopeteMessageManager;
+namespace Kopete { class Account; }
+namespace Kopete { class ChatSession; }
 class KGaduNotify;
 class QString;
 class QStringList;
 
-class GaduContact : public KopeteContact
+class GaduContact : public Kopete::Contact
 {
 	Q_OBJECT
 
 public:
-	GaduContact( unsigned int, const QString&, KopeteAccount*, KopeteMetaContact* );
+	GaduContact( unsigned int, const QString&, Kopete::Account*, Kopete::MetaContact* );
 
 	virtual bool isReachable();
 	virtual void serialize( QMap<QString, QString>&, QMap<QString, QString>& );
@@ -75,9 +75,9 @@ public:
 	
 public slots:
 	void slotUserInfo();
-	void slotDeleteContact();
-	void messageReceived( KopeteMessage& );
-	void messageSend( KopeteMessage&, KopeteMessageManager* );
+	void deleteContact();
+	void messageReceived( Kopete::Message& );
+	void messageSend( Kopete::Message&, Kopete::ChatSession* );
 	void messageAck();
 	void slotShowPublicProfile();
 	void slotEditContact();
@@ -86,14 +86,14 @@ public slots:
 
 
 protected:
-	virtual KopeteMessageManager* manager( bool canCreate = false );
+	virtual Kopete::ChatSession* manager( Kopete::Contact::CanCreateFlags canCreate = Kopete::Contact::CanCreate );
 	void initActions();
 
 private:
 	const uin_t		uin_;
 	bool 			ignored_;
 
-	KopeteMessageManager*	msgManager_;
+	Kopete::ChatSession*	msgManager_;
 	QString			description_;
 	QString			parentIdentity_;
 	GaduAccount*		account_;
@@ -102,7 +102,7 @@ private:
 	KAction*		actionInfo_;
 	KAction*		actionRemove_;
 
-	KopeteContactPtrList	thisContact_;
+	QPtrList<Kopete::Contact>	thisContact_;
 
 
 	QHostAddress remote_ip;
@@ -112,7 +112,7 @@ private:
 
 
 private slots:
-	void slotMessageManagerDestroyed();
+	void slotChatSessionDestroyed();
 
 };
 
