@@ -1,8 +1,9 @@
-/* $Id: dcc.c 417091 2005-05-22 19:40:46Z gj $ */
+/* $Id: dcc.c 572322 2006-08-12 10:20:52Z gj $ */
 
 /*
- *  (C) Copyright 2001-2002 Wojtek Kaniewski <wojtekka@irc.pl>
+ *  (C) Copyright 2001-2006 Wojtek Kaniewski <wojtekka@irc.pl>
  *                          Tomasz Chiliski <chilek@chilan.com>
+ *                          Adam Wysocki <gophi@ekg.chmurka.net>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU Lesser General Public License Version
@@ -92,7 +93,7 @@ int gg_dcc_request(struct gg_session *sess, uin_t uin)
  *  - unix - czas w postaci unixowej
  *  - filetime - czas w postaci windowsowej
  */
-void gg_dcc_fill_filetime(uint32_t ut, uint32_t *ft)
+static void gg_dcc_fill_filetime(uint32_t ut, uint32_t *ft)
 {
 #ifdef __GG_LIBGADU_HAVE_LONG_LONG
 	unsigned long long tmp;
@@ -874,6 +875,7 @@ struct gg_event *gg_dcc_watch_fd(struct gg_dcc *h)
 
 				if (!(h->voice_buf = malloc(h->chunk_size))) {
 					gg_debug(GG_DEBUG_MISC, "// gg_dcc_watch_fd() out of memory for voice frame\n");
+					free(e);
 					return NULL;
 				}
 
