@@ -15,6 +15,14 @@
     *************************************************************************
 */
 
+#include "ircadd.h"
+#include "ircaddcontactpage.h"
+#include "channellist.h"
+
+#include "kircengine.h"
+
+#include "ircaccount.h"
+
 #include <qlayout.h>
 #include <qlineedit.h>
 #include <qframe.h>
@@ -23,12 +31,6 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 
-#include "ircaddcontactpage.h"
-#include "ircadd.h"
-#include "ircaccount.h"
-#include "kirc.h"
-#include "channellist.h"
-
 IRCAddContactPage::IRCAddContactPage( QWidget *parent, IRCAccount *a ) : AddContactPage(parent, 0)
 {
 	(new QVBoxLayout(this))->setAutoAdd(true);
@@ -58,10 +60,10 @@ void IRCAddContactPage::slotChannelDoubleClicked( const QString &channel )
 	ircdata->tabWidget3->setCurrentPage(0);
 }
 
-bool IRCAddContactPage::apply(KopeteAccount *account , KopeteMetaContact *m)
+bool IRCAddContactPage::apply(Kopete::Account *account , Kopete::MetaContact *m)
 {
 	QString name = ircdata->addID->text();
-	return account->addContact(name, name, m, KopeteAccount::ChangeKABC );
+	return account->addContact(name, m, Kopete::Account::ChangeKABC );
 }
 
 bool IRCAddContactPage::validateData()
