@@ -15,26 +15,26 @@
     *************************************************************************
 */
 
-#include <qtimer.h>
+#include "ircusercontact.h"
+#include "ircaccount.h"
+#include "irccontactmanager.h"
+#include "ircprotocol.h"
+#include "ircsignalhandler.h"
+
+#include "ircservercontact.h"
+#include "ircchannelcontact.h"
+
+#include "kircengine.h"
+
+#include <kopeteaccountmanager.h>
+#include <kopetemetacontact.h>
+#include <kopetecontactlist.h>
+#include <kopeteview.h>
 
 #include <kconfig.h>
 #include <kstandarddirs.h>
 
-#include <kopeteaccountmanager.h>
-#include <kopetemetacontact.h>
-#include <kopeteview.h>
-
-#include "kirc.h"
-
-#include "ircaccount.h"
-#include "ircprotocol.h"
-
-#include "ircservercontact.h"
-#include "ircchannelcontact.h"
-#include "ircusercontact.h"
-
-#include "irccontactmanager.h"
-#include "ircsignalhandler.h"
+#include <qtimer.h>
 
 IRCContactManager::IRCContactManager(const QString &nickName, IRCAccount *account, const char *name)
 	: QObject(account, name),
@@ -44,9 +44,9 @@ IRCContactManager::IRCContactManager(const QString &nickName, IRCAccount *accoun
 {
 	m_mySelf = findUser(nickName);
 
-	KopeteMetaContact *m = new KopeteMetaContact();
+	Kopete::MetaContact *m = new Kopete::MetaContact();
 //	m->setTemporary( true );
-	m_myServer = new IRCServerContact(this, account->engine()->currentHost(), m);
+	m_myServer = new IRCServerContact(this, account->networkName(), m);
 
 	QObject::connect(account->engine(), SIGNAL(incomingMessage(const QString &, const QString &, const QString &)),
 			this, SLOT(slotNewMessage(const QString &, const QString &, const QString &)));
@@ -54,12 +54,6 @@ IRCContactManager::IRCContactManager(const QString &nickName, IRCAccount *accoun
 	QObject::connect(account->engine(), SIGNAL(incomingPrivMessage(const QString &, const QString &, const QString &)),
 			this, SLOT(slotNewPrivMessage(const QString &, const QString &, const QString &)));
 
-	QObject::connect(account->engine(), SIGNAL(incomingAction(const QString &, const QString &, const QString &)),
-			this, SLOT(slotNewAction(const QString &, const QString &, const QString &)));
-
-	QObject::connect(account->engine(), SIGNAL(incomingPrivAction(const QString &, const QString &, const QString &)),
-			this, SLOT(slotNewPrivAction(const QString &, const QString &, const QString &)));
-
 	QObject::connect(account->engine(), SIGNAL(incomingNickChange(const QString &, const QString &)),
 			this, SLOT( slotNewNickChange(const QString&, const QString&)));
 
@@ -69,6 +63,9 @@ IRCContactManager::IRCContactManager(const QString &nickName, IRCAccount *accoun
 	QObject::connect(account->engine(), SIGNAL(incomingUserOnline(const QString &)),
 			this, SLOT( slotIsonRecieved()));
 
+	QObject::connect(Kopete::ContactList::self(), SIGNAL(metaContactAdded( Kopete::MetaContact * )),
+			this, SLOT( slotContactAdded( Kopete::MetaContact* )));
+
 	socketTimeout = 15000;
 	QString timeoutPath = locate( "config", "kioslaverc" );
 	if( !timeoutPath.isEmpty() )
@@ -109,13 +106,42 @@ void IRCContactManager::slotNewPrivMessage(const QString &originating, const QSt
 	emit privateMessage(from, to, message);
 }
 
-void IRCContactManager::unregister(KopeteContact *contact)
+void IRCContactManager::unregister(Kopete::Contact *contact)
 {
 	unregisterChannel(contact, true);
 	unregisterUser(contact, true);
 }
 
-IRCChannelContact *IRCContactManager::findChannel(const QString &name, KopeteMetaContact *m)
+QValueList<IRCChannelContact*> IRCContactManager::findChannelsByMember( IRCUserContact *contact )
+{
+	QValueList<IRCChannelContact*> retVal;
+	for( QDictIterator<IRCChannelContact> it(m_channels); it.current(); ++it )
+	{
+		if( it.current()->manager(Kopete::Contact::CannotCreate) )
+		{
+			if( contact == m_mySelf )
+				retVal.push_back( it.current() );
+			else
+			{
+				bool c = true;
+
+				Kopete::ContactPtrList members = it.current()->manager()->members();
+				for( QPtrListIterator<Kopete::Contact> it2( members ); c && it2.current(); ++it2 )
+				{
+					if( it2.current() == contact )
+					{
+						retVal.push_back( it.current() );
+						c = false;
+					}
+				}
+			}
+		}
+	}
+
+	return retVal;
+}
+
+IRCChannelContact *IRCContactManager::findChannel(const QString &name, Kopete::MetaContact *m)
 {
 	IRCChannelContact *channel = m_channels[ name ];
 
@@ -123,14 +149,14 @@ IRCChannelContact *IRCContactManager::findChannel(const QString &name, KopeteMet
 	{
 		if( !m )
 		{
-			m = new KopeteMetaContact();
+			m = new Kopete::MetaContact();
 			m->setTemporary( true );
 		}
 
 		channel = new IRCChannelContact(this, name, m);
 		m_channels.insert( name, channel );
-		QObject::connect(channel, SIGNAL(contactDestroyed(KopeteContact *)),
-			this, SLOT(unregister(KopeteContact *)));
+		QObject::connect(channel, SIGNAL(contactDestroyed(Kopete::Contact *)),
+			this, SLOT(unregister(Kopete::Contact *)));
 	}
 
 	return channel;
@@ -141,7 +167,7 @@ IRCChannelContact *IRCContactManager::existChannel( const QString &channel ) con
 	return m_channels[ channel ];
 }
 
-void IRCContactManager::unregisterChannel(KopeteContact *contact, bool force )
+void IRCContactManager::unregisterChannel(Kopete::Contact *contact, bool force )
 {
 	IRCChannelContact *channel = (IRCChannelContact*)contact;
 	if( force || (
@@ -153,7 +179,7 @@ void IRCContactManager::unregisterChannel(KopeteContact *contact, bool force )
 	}
 }
 
-IRCUserContact *IRCContactManager::findUser(const QString &name, KopeteMetaContact *m)
+IRCUserContact *IRCContactManager::findUser(const QString &name, Kopete::MetaContact *m)
 {
 	IRCUserContact *user = m_users[name.section('!', 0, 0)];
 
@@ -161,14 +187,14 @@ IRCUserContact *IRCContactManager::findUser(const QString &name, KopeteMetaConta
 	{
 		if( !m )
 		{
-			m = new KopeteMetaContact();
+			m = new Kopete::MetaContact();
 			m->setTemporary( true );
 		}
 
 		user = new IRCUserContact(this, name, m);
 		m_users.insert( name, user );
-		QObject::connect(user, SIGNAL(contactDestroyed(KopeteContact *)),
-				this, SLOT(unregister(KopeteContact *)));
+		QObject::connect(user, SIGNAL(contactDestroyed(Kopete::Contact *)),
+				this, SLOT(unregister(Kopete::Contact *)));
 	}
 
 	return user;
@@ -179,18 +205,18 @@ IRCUserContact *IRCContactManager::existUser( const QString &user ) const
 	return m_users[user];
 }
 
-IRCContact *IRCContactManager::findContact( const QString &id, KopeteMetaContact *m )
+IRCContact *IRCContactManager::findContact( const QString &id, Kopete::MetaContact *m )
 {
-	if( KIRCEntity::isChannel(id) )
+	if( KIRC::Entity::isChannel(id) )
 		return findChannel( id, m );
 	else
 		return findUser( id, m );
 }
 
-IRCContact *IRCContactManager::existContact( const KIRC *engine, const QString &id )
+IRCContact *IRCContactManager::existContact( const KIRC::Engine *engine, const QString &id )
 {
-	QDict<KopeteAccount> accounts = KopeteAccountManager::manager()->accounts( IRCProtocol::protocol() );
-	QDictIterator<KopeteAccount> it(accounts);
+	QDict<Kopete::Account> accounts = Kopete::AccountManager::self()->accounts( IRCProtocol::protocol() );
+	QDictIterator<Kopete::Account> it(accounts);
 	for( ; it.current(); ++it )
 	{
 		IRCAccount *account = (IRCAccount *)it.current();
@@ -202,13 +228,13 @@ IRCContact *IRCContactManager::existContact( const KIRC *engine, const QString &
 
 IRCContact *IRCContactManager::existContact( const QString &id ) const
 {
-	if( KIRCEntity::isChannel(id) )
+	if( KIRC::Entity::isChannel(id) )
 		return existChannel( id );
 	else
 		return existUser( id );
 }
 
-void IRCContactManager::unregisterUser(KopeteContact *contact, bool force )
+void IRCContactManager::unregisterUser(Kopete::Contact *contact, bool force )
 {
 	IRCUserContact *user = (IRCUserContact *)contact;
 	if( force || (
@@ -221,6 +247,17 @@ void IRCContactManager::unregisterUser(KopeteContact *contact, bool force )
 	}
 }
 
+void IRCContactManager::slotContactAdded( Kopete::MetaContact *contact )
+{
+	for( QPtrListIterator<Kopete::Contact> it( contact->contacts() ); it.current(); ++it )
+	{
+		if( it.current()->account() == m_account )
+		{
+			addToNotifyList( static_cast<IRCContact*>( it.current() )->nickName() );
+		}
+	}
+}
+
 void IRCContactManager::addToNotifyList(const QString &nick)
 {
  	if (!m_NotifyList.contains(nick.lower()))
@@ -241,7 +278,7 @@ void IRCContactManager::checkOnlineNotifyList()
 	if( m_account->engine()->isConnected() )
 	{
 		isonRecieved = false;
-		m_account->engine()->isOn( m_NotifyList );
+		m_account->engine()->ison( m_NotifyList );
 		//QTimer::singleShot( socketTimeout, this, SLOT( slotIsonTimeout() ) );
 	}
 }
@@ -254,7 +291,7 @@ void IRCContactManager::slotIsonRecieved()
 void IRCContactManager::slotIsonTimeout()
 {
 	if( !isonRecieved )
-		m_account->engine()->quitIRC("", true);
+		m_account->engine()->quit("", true);
 }
 
 #include "irccontactmanager.moc"
