@@ -6,6 +6,7 @@
     copyright            : (C) 2003 by Till Gerken <till@tantalo.net>
 							Based on JabberProtocol by Daniel Stone <dstone@kde.org>
 							and Till Gerken <till@tantalo.net>.
+	copyright            : (C) 2006 by Olivier Goffart <ogoffart at kde.org>
 
 			   Kopete (C) 2001-2003 Kopete developers
 			   <kopete-devel@kde.org>.
@@ -28,6 +29,7 @@
 #include "bsocket.h"
 
 #include "jabberaccount.h"
+#include "jabberbookmarks.h"
 
 #include <time.h>
 
@@ -42,6 +44,8 @@
 #include <kapplication.h>
 #include <kaboutdata.h>
 #include <ksocketbase.h>
+#include <kpassdlg.h>
+#include <kinputdialog.h>
 
 #include "kopetepassword.h"
 #include "kopeteawayaction.h"
@@ -49,6 +53,9 @@
 #include "kopeteuiglobal.h"
 #include "kopetegroup.h"
 #include "kopetecontactlist.h"
+#include "kopeteaccountmanager.h"
+#include "contactaddednotifydialog.h"
+
 #include "jabberconnector.h"
 #include "jabberclient.h"
 #include "jabberprotocol.h"
@@ -57,12 +64,29 @@
 #include "jabberfiletransfer.h"
 #include "jabbercontact.h"
 #include "jabbergroupcontact.h"
+#include "jabbercapabilitiesmanager.h"
+#include "jabbertransport.h"
 #include "dlgjabbersendraw.h"
 #include "dlgjabberservices.h"
 #include "dlgjabberchatjoin.h"
 
 #include <sys/utsname.h>
 
+#ifdef SUPPORT_JINGLE
+#include "voicecaller.h"
+#include "jinglevoicecaller.h"
+
+// NOTE: Disabled for 0.12, will develop them futher in KDE4
+// #include "jinglesessionmanager.h"
+// #include "jinglesession.h"
+// #include "jinglevoicesession.h"
+#include "jinglevoicesessiondialog.h"
+#endif
+
+#define KOPETE_CAPS_NODE "http://kopete.kde.org/jabber/caps"
+
+
+
 JabberAccount::JabberAccount (JabberProtocol * parent, const QString & accountId, const char *name)
 			  :Kopete::PasswordedAccount ( parent, accountId, 0, name )
 {
@@ -74,7 +98,13 @@ JabberAccount::JabberAccount (JabberProtocol * parent, const QString & accountId
 
 	m_resourcePool = 0L;
 	m_contactPool = 0L;
-
+#ifdef SUPPORT_JINGLE
+	m_voiceCaller = 0L;
+	//m_jingleSessionManager = 0L; // NOTE: Disabled for 0.12
+#endif
+	m_bookmarks = new JabberBookmarks(this);
+	m_removing=false;
+	m_notifiedUserCannotBindTransferPort = false;
 	// add our own contact to the pool
 	JabberContact *myContact = contactPool()->addContact ( XMPP::RosterItem ( accountId ), Kopete::ContactList::self()->myself(), false );
 	setMyself( myContact );
@@ -89,14 +119,22 @@ JabberAccount::~JabberAccount ()
 {
 	disconnect ( Kopete::Account::Manual );
 
+	// Remove this account from Capabilities manager.
+	protocol()->capabilitiesManager()->removeAccount( this );
+
 	cleanup ();
+	
+	QMap<QString,JabberTransport*> tranposrts_copy=m_transports;
+	QMap<QString,JabberTransport*>::Iterator it;
+	for ( it = tranposrts_copy.begin(); it != tranposrts_copy.end(); ++it ) 
+		delete it.data();
 }
 
 void JabberAccount::cleanup ()
 {
 
 	delete m_jabberClient;
-
+	
 	m_jabberClient = 0L;
 
 	delete m_resourcePool;
@@ -104,7 +142,14 @@ void JabberAccount::cleanup ()
 
 	delete m_contactPool;
 	m_contactPool = 0L;
+	
+#ifdef SUPPORT_JINGLE
+	delete m_voiceCaller;
+	m_voiceCaller = 0L;
 
+// 	delete m_jingleSessionManager;
+// 	m_jingleSessionManager = 0L;
+#endif
 }
 
 void JabberAccount::setS5BServerPort ( int port )
@@ -115,11 +160,12 @@ void JabberAccount::setS5BServerPort ( int port )
 		return;
 	}
 
-	if ( !m_jabberClient->setS5BServerPort ( port ) )
+	if ( !m_jabberClient->setS5BServerPort ( port ) && !m_notifiedUserCannotBindTransferPort)
 	{
-		KMessageBox::sorry ( Kopete::UI::Global::mainWidget (),
+		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (), KMessageBox::Sorry,
 							 i18n ( "Could not bind Jabber file transfer manager to local port. Please check if the file transfer port is already in use or choose another port in the account settings." ),
 							 i18n ( "Failed to start Jabber File Transfer Manager" ) );
+		m_notifiedUserCannotBindTransferPort = true;
 	}
 
 }
@@ -130,19 +176,34 @@ KActionMenu *JabberAccount::actionMenu ()
 
 	m_actionMenu->popupMenu()->insertSeparator();
 
-	m_actionMenu->insert(new KAction (i18n ("Join Groupchat..."), "jabber_group", 0,
-		this, SLOT (slotJoinNewChat ()), this, "actionJoinChat"));
+	KAction *action;
+	
+	action = new KAction (i18n ("Join Groupchat..."), "jabber_group", 0, this, SLOT (slotJoinNewChat ()), this, "actionJoinChat");
+	m_actionMenu->insert(action);
+	action->setEnabled( isConnected() );
+	
+	action = m_bookmarks->bookmarksAction( m_bookmarks );
+	m_actionMenu->insert(action);
+	action->setEnabled( isConnected() );
+
 
 	m_actionMenu->popupMenu()->insertSeparator();
+	
+	action =  new KAction ( i18n ("Services..."), "jabber_serv_on", 0,
+							this, SLOT ( slotGetServices () ), this, "actionJabberServices");
+	action->setEnabled( isConnected() );
+	m_actionMenu->insert ( action );
 
-	m_actionMenu->insert ( new KAction ( i18n ("Services..."), "jabber_serv_on", 0,
-										 this, SLOT ( slotGetServices () ), this, "actionJabberServices") );
+	action = new KAction ( i18n ("Send Raw Packet to Server..."), "mail_new", 0,
+										 this, SLOT ( slotSendRaw () ), this, "actionJabberSendRaw") ;
+	action->setEnabled( isConnected() );
+	m_actionMenu->insert ( action );
 
-	m_actionMenu->insert ( new KAction ( i18n ("Send Raw Packet to Server..."), "mail_new", 0,
-										 this, SLOT ( slotSendRaw () ), this, "actionJabberSendRaw") );
+	action = new KAction ( i18n ("Edit User Info..."), "identity", 0,
+										 this, SLOT ( slotEditVCard () ), this, "actionEditVCard") ;
+	action->setEnabled( isConnected() );
+	m_actionMenu->insert ( action );
 
-	m_actionMenu->insert ( new KAction ( i18n ("Edit User Info..."), "identity", 0,
-										 this, SLOT ( slotEditVCard () ), this, "actionEditVCard") );
 
 	return m_actionMenu;
 
@@ -201,25 +262,7 @@ void JabberAccount::errorConnectFirst ()
 
 void JabberAccount::errorConnectionLost ()
 {
-
-	KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
-									KMessageBox::Error,
-									i18n ("Your connection to the server has been lost in the meantime. "
-									"This means that your last action could not complete successfully. "
-									"Please reconnect and try again."), i18n ("Jabber Error") );
-
-}
-
-void JabberAccount::errorConnectionInProgress ()
-{
-
-	KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
-									KMessageBox::Information,
-									i18n ("A connection attempt is already in progress. "
-									"Please wait until the previous attempt finished or "
-									"disconnect to start over."),
-									i18n ("Connection Attempt Already in Progress") );
-
+	disconnected( Kopete::Account::ConnectionReset );
 }
 
 bool JabberAccount::isConnecting ()
@@ -263,7 +306,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 		QObject::connect ( m_jabberClient, SIGNAL ( rosterRequestFinished ( bool ) ),
 				   this, SLOT ( slotRosterRequestFinished ( bool ) ) );
 		QObject::connect ( m_jabberClient, SIGNAL ( newContact ( const XMPP::RosterItem & ) ),
-				   this, SLOT ( slotNewContact ( const XMPP::RosterItem & ) ) );
+				   this, SLOT ( slotContactUpdated ( const XMPP::RosterItem & ) ) );
 		QObject::connect ( m_jabberClient, SIGNAL ( contactUpdated ( const XMPP::RosterItem & ) ),
 				   this, SLOT ( slotContactUpdated ( const XMPP::RosterItem & ) ) );
 		QObject::connect ( m_jabberClient, SIGNAL ( contactDeleted ( const XMPP::RosterItem & ) ),
@@ -322,7 +365,19 @@ void JabberAccount::connectWithPassword ( const QString &password )
 		m_jabberClient->setClientVersion (kapp->aboutData ()->version ());
 		m_jabberClient->setOSName (QString ("%1 %2").arg (utsBuf.sysname, 1).arg (utsBuf.release, 2));
 	}
+
+	// Set caps node information
+	m_jabberClient->setCapsNode(KOPETE_CAPS_NODE);
+	m_jabberClient->setCapsVersion(kapp->aboutData()->version());
 	
+	// Set Disco Identity information
+	DiscoItem::Identity identity;
+	identity.category = "client";
+	identity.type = "pc";
+	identity.name = "Kopete";
+	m_jabberClient->setDiscoIdentity(identity);
+
+	//BEGIN TIMEZONE INFORMATION
 	//
 	// Set timezone information (code from Psi)
 	// Copyright (C) 2001-2003  Justin Karneges
@@ -351,7 +406,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 
 	if ( strcmp ( fmt, str ) )
 		timezoneString = str;
-	// end of timezone code
+	//END of timezone code
 
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Determined timezone " << timezoneString << " with UTC offset " << timezoneOffset << " hours." << endl;
 
@@ -374,6 +429,7 @@ void JabberAccount::connectWithPassword ( const QString &password )
 		case JabberClient::Ok:
 		default:
 			// everything alright!
+
 			break;
 	}
 
@@ -482,7 +538,7 @@ void JabberAccount::slotClientError ( JabberClient::ErrorCode errorCode )
 	{
 		case JabberClient::NoTLS:
 		default:
-			KMessageBox::error ( Kopete::UI::Global::mainWidget (),
+			KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (), KMessageBox::Error,
 					     i18n ("An encrypted connection with the Jabber server could not be established."),
 					     i18n ("Jabber Connection Error"));
 			disconnect ( Kopete::Account::Manual );
@@ -494,18 +550,33 @@ void JabberAccount::slotClientError ( JabberClient::ErrorCode errorCode )
 void JabberAccount::slotConnected ()
 {
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Connected to Jabber server." << endl;
+	
+#ifdef SUPPORT_JINGLE
+	if(!m_voiceCaller)
+	{
+		kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Creating Jingle Voice caller..." << endl;
+		m_voiceCaller = new JingleVoiceCaller( this );
+		QObject::connect(m_voiceCaller,SIGNAL(incoming(const Jid&)),this,SLOT(slotIncomingVoiceCall( const Jid& )));
+		m_voiceCaller->initialize();
+	}
+	
+
+
+#if 0
+	if(!m_jingleSessionManager)
+	{
+		kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Creating Jingle Session Manager..." << endl;
+		m_jingleSessionManager = new JingleSessionManager( this );
+		QObject::connect(m_jingleSessionManager, SIGNAL(incomingSession(const QString &, JingleSession *)), this, SLOT(slotIncomingJingleSession(const QString &, JingleSession *)));
+	}
+#endif
+
+	// Set caps extensions
+	m_jabberClient->client()->addExtension("voice-v1", Features(QString("http://www.google.com/xmpp/protocol/voice/v1")));
+#endif
 
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Requesting roster..." << endl;
 	m_jabberClient->requestRoster ();
-
-	/* Since we are online now, set initial presence. Don't do this
-	 * before the roster request or we will receive presence
-	 * information before we have updated our roster with actual
-	 * contacts from the server! (Iris won't forward presence
-	 * information in that case either). */
-	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Setting initial presence..." << endl;
-	setPresence ( m_initialPresence );
-
 }
 
 void JabberAccount::slotRosterRequestFinished ( bool success )
@@ -518,6 +589,14 @@ void JabberAccount::slotRosterRequestFinished ( bool success )
 		contactPool()->cleanUp ();
 	}
 
+	/* Since we are online now, set initial presence. Don't do this
+	* before the roster request or we will receive presence
+	* information before we have updated our roster with actual
+	* contacts from the server! (Iris won't forward presence
+	* information in that case either). */
+	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Setting initial presence..." << endl;
+	setPresence ( m_initialPresence );
+
 }
 
 void JabberAccount::slotIncomingFileTransfer ()
@@ -530,52 +609,27 @@ void JabberAccount::slotIncomingFileTransfer ()
 
 void JabberAccount::setOnlineStatus( const Kopete::OnlineStatus& status  , const QString &reason)
 {
+	XMPP::Status xmppStatus = m_protocol->kosToStatus( status, reason);
+
 	if( status.status() == Kopete::OnlineStatus::Offline )
 	{
-		disconnect( Kopete::Account::Manual );
-		return;
-	}
+			xmppStatus.setIsAvailable( false );
+			kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "CROSS YOUR FINGERS! THIS IS GONNA BE WILD" << endl;
+            disconnect (Manual, xmppStatus);
+            return;
+    }
 
 	if( isConnecting () )
 	{
-		errorConnectionInProgress ();
 		return;
 	}
-
-	XMPP::Status xmppStatus ( "", reason );
-
-	switch ( status.internalStatus () )
-	{
-		case JabberProtocol::JabberFreeForChat:
-			xmppStatus.setShow ( "chat" );
-			break;
-
-		case JabberProtocol::JabberOnline:
-			xmppStatus.setShow ( "" );
-			break;
-
-		case JabberProtocol::JabberAway:
-			xmppStatus.setShow ( "away" );
-			break;
-
-		case JabberProtocol::JabberXA:
-			xmppStatus.setShow ( "xa" );
-			break;
-
-		case JabberProtocol::JabberDND:
-			xmppStatus.setShow ( "dnd" );
-			break;
-
-		case JabberProtocol::JabberInvisible:
-			xmppStatus.setIsInvisible ( true );
-			break;
-	}
+	
 
 	if ( !isConnected () )
 	{
 		// we are not connected yet, so connect now
 		m_initialPresence = xmppStatus;
-		connect ();
+		connect ( status );
 	}
 	else
 	{
@@ -597,6 +651,35 @@ void JabberAccount::disconnect ( Kopete::Account::DisconnectReason reason )
 	// make sure that the connection animation gets stopped if we're still
 	// in the process of connecting
 	setPresence ( XMPP::Status ("", "", 0, false) );
+	m_initialPresence = XMPP::Status ("", "", 5, true);
+
+	/* FIXME:
+	 * We should delete the JabberClient instance here,
+	 * but active timers in Iris prevent us from doing so.
+	 * (in a failed connection attempt, these timers will
+	 * try to access an already deleted object).
+	 * Instead, the instance will lurk until the next
+	 * connection attempt.
+	 */
+	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Disconnected." << endl;
+
+	disconnected ( reason );
+}
+
+void JabberAccount::disconnect( Kopete::Account::DisconnectReason reason, XMPP::Status &status )
+{
+    kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "disconnect( reason, status ) called" << endl;
+    
+	if (isConnected ())
+	{
+		kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Still connected, closing connection..." << endl;
+		/* Tell backend class to disconnect. */
+		m_jabberClient->disconnect (status);
+	}
+
+	// make sure that the connection animation gets stopped if we're still
+	// in the process of connecting
+	setPresence ( status );
 
 	/* FIXME:
 	 * We should delete the JabberClient instance here,
@@ -711,6 +794,7 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 			switch(connectorCode)
 			{
  				case KNetwork::KSocketBase::LookupFailure:
+					errorClass = Kopete::Account::InvalidHost;
 					errorCondition = i18n("Host not found.");
 					break;
 				case KNetwork::KSocketBase::AddressInUse:
@@ -756,11 +840,12 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 					errorCondition = i18n("Socket timed out.");
 					break;
 				default:
-					errorCondition = i18n("Sorry, something unexpected happened that I do not know more about.");
+					errorClass = Kopete::Account::ConnectionReset;
+					//errorCondition = i18n("Sorry, something unexpected happened that I do not know more about.");
 					break;
 			}
-
-			errorText = i18n("There was a connection error: %1").arg(errorCondition);
+			if(!errorCondition.isEmpty())
+				errorText = i18n("There was a connection error: %1").arg(errorCondition);
 			break;
 
 		case XMPP::ClientStream::ErrNeg:
@@ -893,7 +978,8 @@ void JabberAccount::handleStreamError (int streamError, int streamCondition, int
 	 * API will attempt to reconnect, queueing another
 	 * error until memory is exhausted.
 	 */
-	KMessageBox::error (Kopete::UI::Global::mainWidget (),
+	if(!errorText.isEmpty())
+		KMessageBox::error (Kopete::UI::Global::mainWidget (),
 						errorText,
 						i18n("Connection problem with Jabber server %1").arg(server));
 
@@ -908,23 +994,22 @@ void JabberAccount::slotCSError ( int error )
 		&& ( client()->clientStream()->errorCondition () == XMPP::ClientStream::NotAuthorized ) )
 	{
 		kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Incorrect password, retrying." << endl;
-
-		// FIXME: This should be unified in libkopete as disconnect(IncorrectPassword)
-		password().setWrong ();
-		disconnect ();
-		connect ();
+		disconnect(Kopete::Account::BadPassword);
 	}
 	else
 	{
-		Kopete::Account::DisconnectReason errorClass;
+		Kopete::Account::DisconnectReason errorClass =  Kopete::Account::Unknown;
 
 		kdDebug ( JABBER_DEBUG_GLOBAL ) << k_funcinfo << "Disconnecting." << endl;
 
 		// display message to user
-		handleStreamError (error, client()->clientStream()->errorCondition (), client()->clientConnector()->errorCode (), server (), errorClass);
+		if(!m_removing) //when removing the account, connection errors are normal.
+			handleStreamError (error, client()->clientStream()->errorCondition (), client()->clientConnector()->errorCode (), server (), errorClass);
 
 		disconnect ( errorClass );
-
+		
+		/*	slotCSDisconnected  will not be called*/
+		resourcePool()->clear();
 	}
 
 }
@@ -936,6 +1021,15 @@ void JabberAccount::setPresence ( const XMPP::Status &status )
 
 	// fetch input status
 	XMPP::Status newStatus = status;
+	
+	// TODO: Check if Caps is enabled
+	// Send entity capabilities
+	if( client() )
+	{
+		newStatus.setCapsNode( client()->capsNode() );
+		newStatus.setCapsVersion( client()->capsVersion() );
+		newStatus.setCapsExt( client()->capsExt() );
+	}
 
 	// make sure the status gets the correct priority
 	newStatus.setPriority ( configGroup()->readNumEntry ( "Priority", 5 ) );
@@ -998,91 +1092,28 @@ void JabberAccount::slotSubscription (const XMPP::Jid & jid, const QString & typ
 		 */
 		kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << jid.full () << " is asking for authorization to subscribe." << endl;
 
+		// Is the user already in our contact list?
+		JabberBaseContact *contact = contactPool()->findExactMatch( jid );
 		Kopete::MetaContact *metaContact=0L;
-		Kopete::Contact *contact;
-		XMPP::JT_Presence *task;
-
-		switch (KMessageBox::questionYesNoCancel (Kopete::UI::Global::mainWidget (),
-												  i18n
-												  ("The Jabber user %1 wants to add you to their "
-												   "contact list; do you want to authorize them? "
-												   "Selecting Cancel will ignore the request.").
-												  arg (jid.userHost (), 1), i18n ("Authorize Jabber User?"), i18n ("Authorize"), i18n ("Deny")))
-		{
-			case KMessageBox::Yes:
-				/*
-				 * Authorize user.
-				 */
-
-				// this safety check needs to be here because
-				// a long time could have passed between the
-				// actual request and the user's answer
-				if ( !isConnected () )
-				{
-					errorConnectionLost ();
-					break;
-				}
-
-				task = new XMPP::JT_Presence ( client()->rootTask () );
-
-				task->sub ( jid, "subscribed" );
-				task->go ( true );
-
-				// Is the user already in our contact list?
-				contact = Kopete::ContactList::self ()->findContact (protocol ()->pluginId (), accountId (), jid.full().lower () );
-				if(contact)
-					metaContact=contact->metaContact();
-
-				// If it is not, ask the user if he wants to subscribe in return.
-				if ( ( !metaContact || metaContact->isTemporary() ) &&
-					 ( KMessageBox::questionYesNo (Kopete::UI::Global::mainWidget (),
-												   i18n ( "Do you want to add %1 to your contact list in return?").
-												   arg (jid.userHost (), 1), i18n ("Add Jabber User?"),i18n("Add"), i18n("Do Not Add")) == KMessageBox::Yes) )
-				{
-					// Subscribe to user's presence.
-					task = new XMPP::JT_Presence ( client()->rootTask () );
-
-					task->sub ( jid, "subscribe" );
-					task->go ( true );
-				}
-
-				break;
-
-			case KMessageBox::No:
-				/*
-				 * Reject subscription.
-				 */
-
-				// this safety check needs to be here because
-				// a long time could have passed between the
-				// actual request and the user's answer
-				if ( !isConnected () )
-				{
-					errorConnectionLost ();
-					break;
-				}
-
-				task = new XMPP::JT_Presence ( client()->rootTask () );
-
-				task->sub ( jid, "unsubscribed" );
-				task->go ( true );
-
-				break;
-
-			case KMessageBox::Cancel:
-				/*
-				 * Simply ignore the request.
-				 */
-				break;
-		}
-
+		if(contact)
+			metaContact=contact->metaContact();
+		
+		int hideFlags=Kopete::UI::ContactAddedNotifyDialog::InfoButton;
+		if( metaContact && !metaContact->isTemporary() )
+			hideFlags |= Kopete::UI::ContactAddedNotifyDialog::AddCheckBox | Kopete::UI::ContactAddedNotifyDialog::AddGroupBox ;
+		
+		Kopete::UI::ContactAddedNotifyDialog *dialog=
+				new Kopete::UI::ContactAddedNotifyDialog( jid.full() ,QString::null,this, hideFlags );
+		QObject::connect(dialog,SIGNAL(applyClicked(const QString&)),
+						this,SLOT(slotContactAddedNotifyDialogClosed(const QString& )));
+		dialog->show();
 	}
 	else if (type == "unsubscribed")
 	{
 		/*
 		 * Someone else removed our authorization to see them.
 		 */
-		kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << jid.userHost () << " revoked our presence authorization" << endl;
+		kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << jid.full() << " revoked our presence authorization" << endl;
 
 		XMPP::JT_Roster *task;
 
@@ -1091,7 +1122,7 @@ void JabberAccount::slotSubscription (const XMPP::Jid & jid, const QString & typ
 								  ("The Jabber user %1 removed %2's subscription to them. "
 								   "This account will no longer be able to view their online/offline status. "
 								   "Do you want to delete the contact?").
-								  arg (jid.userHost (), 1).arg (accountId(), 2), i18n ("Notification"), KStdGuiItem::del(), i18n("Keep")))
+										  arg (jid.full(), 1).arg (accountId(), 2), i18n ("Notification"), KStdGuiItem::del(), i18n("Keep")))
 		{
 
 			case KMessageBox::Yes:
@@ -1119,7 +1150,73 @@ void JabberAccount::slotSubscription (const XMPP::Jid & jid, const QString & typ
 	}
 }
 
-void JabberAccount::slotNewContact (const XMPP::RosterItem & item)
+void JabberAccount::slotContactAddedNotifyDialogClosed( const QString & contactid )
+{	// the dialog that asked the authorisation is closed. (it was shown in slotSubscrition)
+	
+	XMPP::JT_Presence *task;
+	XMPP::Jid jid(contactid);
+
+	const Kopete::UI::ContactAddedNotifyDialog *dialog =
+			dynamic_cast<const Kopete::UI::ContactAddedNotifyDialog *>(sender());
+	if(!dialog || !isConnected())
+		return;
+
+	if ( dialog->authorized() )
+	{
+		/*
+		* Authorize user.
+		*/
+
+		task = new XMPP::JT_Presence ( client()->rootTask () );
+		task->sub ( jid, "subscribed" );
+		task->go ( true );
+	}
+	else
+	{
+		/*
+		* Reject subscription.
+		*/
+		task = new XMPP::JT_Presence ( client()->rootTask () );
+		task->sub ( jid, "unsubscribed" );
+		task->go ( true );
+	}
+
+
+	if(dialog->added())
+	{
+		Kopete::MetaContact *parentContact=dialog->addContact();
+		if(parentContact)
+		{
+			QStringList groupNames;
+			Kopete::GroupList groupList = parentContact->groups();
+			for(Kopete::Group *group = groupList.first(); group; group = groupList.next())
+				groupNames += group->displayName();
+
+			XMPP::RosterItem item;
+//			XMPP::Jid jid ( contactId );
+
+			item.setJid ( jid );
+			item.setName ( parentContact->displayName() );
+			item.setGroups ( groupNames );
+
+			// add the new contact to our roster.
+			XMPP::JT_Roster * rosterTask = new XMPP::JT_Roster ( client()->rootTask () );
+
+			rosterTask->set ( item.jid(), item.name(), item.groups() );
+			rosterTask->go ( true );
+
+			// send a subscription request.
+			XMPP::JT_Presence *presenceTask = new XMPP::JT_Presence ( client()->rootTask () );
+	
+			presenceTask->sub ( jid, "subscribe" );
+			presenceTask->go ( true );
+		}
+	}
+}
+
+
+
+void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
 {
 
 	/**
@@ -1139,51 +1236,86 @@ void JabberAccount::slotNewContact (const XMPP::RosterItem & item)
 
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "New roster item " << item.jid().full () << " (Subscription: " << item.subscription().toString () << ")" << endl;
 
+	/*
+	 * See if the contact need to be added, according to the criterias of 
+	 *  JEP-0162: Best Practices for Roster and Subscription Management
+	 * http://www.jabber.org/jeps/jep-0162.html#contacts
+	 */
+	bool need_to_add=false;
+	if(item.subscription().type() == XMPP::Subscription::Both || item.subscription().type() == XMPP::Subscription::To)
+		need_to_add = true;
+	else if( !item.ask().isEmpty() )
+		need_to_add = true;
+	else if( !item.name().isEmpty() || !item.groups().isEmpty() )
+		need_to_add = true;
+	
 	/*
 	 * See if the contact is already on our contact list
 	 */
-	Kopete::MetaContact *metaContact;
-	Kopete::Contact *c= Kopete::ContactList::self()->findContact ( protocol()->pluginId (), accountId (), item.jid().full().lower () ) ;
-	if ( !c  )
+	Kopete::Contact *c= contactPool()->findExactMatch( item.jid() );
+	
+	if( c && c == c->Kopete::Contact::account()->myself() )  //don't use JabberBaseContact::account() which return alwaus the JabberAccount, and not the transport
 	{
+		// don't let remove the gateway contact, eh!
+		need_to_add = true;  
+	}
+
+	if(need_to_add)
+	{
+		Kopete::MetaContact *metaContact=0L;
+		if (!c)
+		{
+			/*
+			* No metacontact has been found which contains a contact with this ID,
+			* so add a new metacontact to the list.
+			*/
+			metaContact = new Kopete::MetaContact ();
+			QStringList groups = item.groups ();
+	
+			// add this metacontact to all groups the contact is a member of
+			for (QStringList::Iterator it = groups.begin (); it != groups.end (); ++it)
+				metaContact->addToGroup (Kopete::ContactList::self ()->findGroup (*it));
+	
+			// put it onto contact list
+			Kopete::ContactList::self ()->addMetaContact ( metaContact );
+		}
+		else
+		{
+			metaContact=c->metaContact();
+			//TODO: syncronize groups
+		}
+
 		/*
-		 * No metacontact has been found which contains a contact with this ID,
-		 * so add a new metacontact to the list.
-		 */
-		metaContact = new Kopete::MetaContact ();
-		QStringList groups = item.groups ();
+		* Add / update the contact in our pool. In case the contact is already there,
+		* it will be updated. In case the contact is not in the meta contact yet, it
+		* will be added to it.
+		* The "dirty" flag is false here, because we just received the contact from
+		* the server's roster. As such, it is now a synchronized entry.
+		*/
+		JabberContact *contact = contactPool()->addContact ( item, metaContact, false );
 
-		// add this metacontact to all groups the contact is a member of
-		for (QStringList::Iterator it = groups.begin (); it != groups.end (); ++it)
-			metaContact->addToGroup (Kopete::ContactList::self ()->findGroup (*it));
-
-		// put it onto contact list
-		Kopete::ContactList::self ()->addMetaContact ( metaContact );
+		/*
+		* Set authorization property
+		*/
+		if ( !item.ask().isEmpty () )
+		{
+			contact->setProperty ( protocol()->propAuthorizationStatus, i18n ( "Waiting for authorization" ) );
+		}
+		else
+		{
+			contact->removeProperty ( protocol()->propAuthorizationStatus );
+		}
 	}
-	else
+	else if(c)  //we don't need to add it, and it is in the contactlist
 	{
-		metaContact=c->metaContact();
-	}
-
-	/*
-	 * Add / update the contact in our pool. In case the contact is already there,
-	 * it will be updated. In case the contact is not in the meta contact yet, it
-	 * will be added to it.
-	 * The "dirty" flag is false here, because we just received the contact from
-	 * the server's roster. As such, it is now a synchronized entry.
-	 */
-	JabberContact *contact = contactPool()->addContact ( item, metaContact, false );
-
-	/*
-	 * Set authorization property
-	 */
-	if ( !item.ask().isEmpty () )
-	{
-		contact->setProperty ( protocol()->propAuthorizationStatus, i18n ( "Waiting for authorization" ) );
-	}
-	else
-	{
-		contact->removeProperty ( protocol()->propAuthorizationStatus );
+		Kopete::MetaContact *metaContact=c->metaContact();
+		if(metaContact->isTemporary())
+			return;
+		kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << c->contactId() << 
+				" is on the contactlist while it shouldn't.  we are removing it.  - " << c << endl;
+		delete c;
+		if(metaContact->contacts().isEmpty())
+			Kopete::ContactList::self()->removeMetaContact( metaContact );
 	}
 
 }
@@ -1197,31 +1329,6 @@ void JabberAccount::slotContactDeleted (const XMPP::RosterItem & item)
 
 }
 
-void JabberAccount::slotContactUpdated (const XMPP::RosterItem & item)
-{
-	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Status update for " << item.jid().full () << endl;
-
-	/*
-	 * Sanity check: make sure that we have a matchin contact
-	 * in our local pool before we try to updating it.
-	 * (if no contact would be present, we'd add a contact
-	 * without parent meta contact)
-	 */
-	if ( !contactPool()->findExactMatch ( item.jid () ) )
-	{
-		kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "WARNING: Trying to update non-existing contact " << item.jid().full () << endl;
-		return;
-	}
-
-	/*
-	 * Adding the contact again will update the existing instance.
-	 * We're also explicitely setting the dirty flag to "false" since
-	 * we are in synch with the server.
-	 */
-	contactPool()->addContact ( item, 0L, false );
-
-}
-
 void JabberAccount::slotReceivedMessage (const XMPP::Message & message)
 {
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "New message from " << message.from().full () << endl;
@@ -1315,10 +1422,15 @@ void JabberAccount::slotGroupChatJoined (const XMPP::Jid & jid)
 	// Create a groupchat contact for this room
 	JabberGroupContact *groupContact = dynamic_cast<JabberGroupContact *>( contactPool()->addGroupContact ( XMPP::RosterItem ( jid ), true, metaContact, false ) );
 
-	// Add the groupchat contact to the meta contact.
-	metaContact->addContact ( groupContact );
-
-	Kopete::ContactList::self ()->addMetaContact ( metaContact );
+	if(groupContact)
+	{
+		// Add the groupchat contact to the meta contact.
+		//metaContact->addContact ( groupContact );
+	
+		Kopete::ContactList::self ()->addMetaContact ( metaContact );
+	}
+	else
+		delete metaContact;
 
 	/**
 	 * Add an initial resource for this contact to the pool. We need
@@ -1331,22 +1443,30 @@ void JabberAccount::slotGroupChatJoined (const XMPP::Jid & jid)
 
 	// lock the room to our own status
 	resourcePool()->lockToResource ( XMPP::Jid ( jid.userHost () ), jid.resource () );
-
+	
+	m_bookmarks->insertGroupChat(jid);	
 }
 
 void JabberAccount::slotGroupChatLeft (const XMPP::Jid & jid)
 {
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo "Left groupchat " << jid.full () << endl;
-
+	
 	// remove group contact from list
-	Kopete::MetaContact *metaContact = Kopete::ContactList::self()->findMetaContactByContactId ( jid.userHost () );
+	Kopete::Contact *contact = 
+			Kopete::ContactList::self()->findContact( protocol()->pluginId() , accountId() , jid.userHost() );
 
-	if ( metaContact )
-		Kopete::ContactList::self()->removeMetaContact ( metaContact );
+	if ( contact )
+	{
+		Kopete::MetaContact *metaContact= contact->metaContact();
+		if( metaContact && metaContact->isTemporary() )
+			Kopete::ContactList::self()->removeMetaContact ( metaContact );
+		else
+			contact->deleteLater();
+	}
 
 	// now remove it from our pool, which should clean up all subcontacts as well
 	contactPool()->removeContact ( XMPP::Jid ( jid.userHost () ) );
-
+	
 }
 
 void JabberAccount::slotGroupChatPresence (const XMPP::Jid & jid, const XMPP::Status & status)
@@ -1387,18 +1507,61 @@ void JabberAccount::slotGroupChatError (const XMPP::Jid &jid, int error, const Q
 {
 	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Group chat error - room " << jid.full () << " had error " << error << " (" << reason << ")" << endl;
 
-	QString detailedReason = reason.isEmpty () ? i18n ( "No reason given by the server" ) : reason;
+	switch (error)
+	{
+	case JabberClient::InvalidPasswordForMUC:
+		{
+			QCString password;
+ 			int result = KPasswordDialog::getPassword(password, i18n("A password is required to join the room %1.").arg(jid.node()));
+			if (result == KPasswordDialog::Accepted)
+				m_jabberClient->joinGroupChat(jid.domain(), jid.node(), jid.resource(), password);
+		}
+		break;
 
-	KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
+	case JabberClient::NicknameConflict:
+		{
+			bool ok;
+			QString nickname = KInputDialog::getText(i18n("Error trying to join %1 : nickname %2 is already in use").arg(jid.node(), jid.resource()),
+									i18n("Give your nickname"),
+									QString(),
+									&ok);
+			if (ok)
+			{
+				m_jabberClient->joinGroupChat(jid.domain(), jid.node(), nickname);
+			}
+		}
+		break;
+
+	case JabberClient::BannedFromThisMUC:
+		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
+									KMessageBox::Error,
+									i18n ("You can't join the room %1 because you were banned").arg(jid.node()),
+									i18n ("Jabber Group Chat") );
+		break;
+
+	case JabberClient::MaxUsersReachedForThisMuc:
+		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
+									KMessageBox::Error,
+									i18n ("You can't join the room %1 because the maximum users has been reached").arg(jid.node()),
+									i18n ("Jabber Group Chat") );
+		break;
+
+	default:
+		{
+		QString detailedReason = reason.isEmpty () ? i18n ( "No reason given by the server" ) : reason;
+
+		KMessageBox::queuedMessageBox ( Kopete::UI::Global::mainWidget (),
 									KMessageBox::Error,
 									i18n ("There was an error processing your request for group chat %1. (Reason: %2, Code %3)").arg ( jid.full (), detailedReason, QString::number ( error ) ),
 									i18n ("Jabber Group Chat") );
+		}
+	}
 }
 
 void JabberAccount::slotResourceAvailable (const XMPP::Jid & jid, const XMPP::Resource & resource)
 {
 
-	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "New resource available for " << jid.userHost () << endl;
+	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "New resource available for " << jid.full() << endl;
 
 	resourcePool()->addResource ( jid, resource );
 
@@ -1407,7 +1570,7 @@ void JabberAccount::slotResourceAvailable (const XMPP::Jid & jid, const XMPP::Re
 void JabberAccount::slotResourceUnavailable (const XMPP::Jid & jid, const XMPP::Resource & resource)
 {
 
-	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Resource now unavailable for " << jid.userHost () << endl;
+	kdDebug (JABBER_DEBUG_GLOBAL) << k_funcinfo << "Resource now unavailable for " << jid.full () << endl;
 
 	resourcePool()->removeResource ( jid, resource );
 
@@ -1420,16 +1583,28 @@ void JabberAccount::slotEditVCard ()
 
 void JabberAccount::slotGlobalIdentityChanged (const QString &key, const QVariant &value)
 {
-	JabberContact *jabberMyself = static_cast<JabberContact *>( myself() );
-	if( key == Kopete::Global::Properties::self()->nickName().key() )
+	// Check if this account is excluded from Global Identity.
+	if( !configGroup()->readBoolEntry("ExcludeGlobalIdentity", false) )
 	{
-		QString oldNick = jabberMyself->property( protocol()->propNickName ).value().toString();
-		QString newNick = value.toString();
-	
-		if( newNick != oldNick && isConnected() )
+		JabberContact *jabberMyself = static_cast<JabberContact *>( myself() );
+		if( key == Kopete::Global::Properties::self()->nickName().key() )
 		{
-			jabberMyself->setProperty( protocol()->propNickName, newNick );
-			jabberMyself->slotSendVCard();
+			QString oldNick = jabberMyself->property( protocol()->propNickName ).value().toString();
+			QString newNick = value.toString();
+		
+			if( newNick != oldNick && isConnected() )
+			{
+				jabberMyself->setProperty( protocol()->propNickName, newNick );
+				jabberMyself->slotSendVCard();
+			}
+		}
+		if( key == Kopete::Global::Properties::self()->photo().key() )
+		{
+			if( isConnected() )
+			{
+				jabberMyself->setPhoto( value.toString() );
+				jabberMyself->slotSendVCard();
+			}
 		}
 	}
 }
@@ -1463,6 +1638,115 @@ void JabberAccount::slotGetServices ()
 	dialog->raise ();
 }
 
+void JabberAccount::slotIncomingVoiceCall( const Jid &jid )
+{
+	kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << endl;
+#ifdef SUPPORT_JINGLE
+	if(voiceCaller())
+	{
+		kdDebug(JABBER_DEBUG_GLOBAL) << k_funcinfo << "Showing voice dialog." << endl;
+		JingleVoiceSessionDialog *voiceDialog = new JingleVoiceSessionDialog( jid, voiceCaller() );
+		voiceDialog->show();
+	}
+#else
+	Q_UNUSED(jid);
+#endif
+}
+
+// void JabberAccount::slotIncomingJingleSession( const QString &sessionType, JingleSession *session )
+// {
+// #ifdef SUPPORT_JINGLE
+// 	if(sessionType == "http://www.google.com/session/phone")
+// 	{
+// 		QString from = ((XMPP::Jid)session->peers().first()).full();
+// 		//KMessageBox::queuedMessageBox( Kopete::UI::Global::mainWidget(), KMessageBox::Information, QString("Received a voice session invitation from %1.").arg(from) );
+// 		JingleVoiceSessionDialog *voiceDialog = new JingleVoiceSessionDialog( static_cast<JingleVoiceSession*>(session) );
+// 		voiceDialog->show();
+// 	}
+// #else
+// 	Q_UNUSED( sessionType );
+// 	Q_UNUSED( session );
+// #endif
+// }
+
+
+void JabberAccount::addTransport( JabberTransport * tr, const QString &jid )
+{
+	m_transports.insert(jid,tr);
+}
+
+void JabberAccount::removeTransport( const QString &jid )
+{
+	m_transports.remove(jid);
+}
+
+bool JabberAccount::removeAccount( )
+{
+	if(!m_removing)
+	{
+		int result=KMessageBox::warningYesNoCancel( Kopete::UI::Global::mainWidget () ,
+				   i18n( "Do you want to also unregister \"%1\" from the Jabber server ?\n"
+				   			    "If you unregister, all your contact list may be removed on the server,"
+							    "And you will never be able to connect to this account with any client").arg( accountLabel() ),
+					i18n("Unregister"),
+					KGuiItem(i18n( "Remove and Unregister" ), "editdelete"),
+					KGuiItem(i18n( "Remove from kopete only"), "edittrash"),
+					QString(), KMessageBox::Notify | KMessageBox::Dangerous );
+		if(result == KMessageBox::Cancel)
+		{
+			return false;
+		}
+		else if(result == KMessageBox::Yes)
+		{
+			if (!isConnected())
+			{
+				errorConnectFirst ();
+				return false;
+			}
+			
+			XMPP::JT_Register *task = new XMPP::JT_Register ( client()->rootTask () );
+			QObject::connect ( task, SIGNAL ( finished () ), this, SLOT ( slotUnregisterFinished ) );
+			task->unreg ();
+			task->go ( true );
+			m_removing=true;
+			// from my experiment, not all server reply us with a response.   it simply dosconnect
+			// so after one seconde, we will force to remove the account
+			QTimer::singleShot(1111, this, SLOT(slotUnregisterFinished())); 
+			
+			return false; //the account will be removed when the task will be finished
+		}
+	}
+	
+	//remove transports from config file.
+	QMap<QString,JabberTransport*> tranposrts_copy=m_transports;
+	QMap<QString,JabberTransport*>::Iterator it;
+	for ( it = tranposrts_copy.begin(); it != tranposrts_copy.end(); ++it )
+	{
+		(*it)->jabberAccountRemoved();
+	}
+	return true;
+}
+
+void JabberAccount::slotUnregisterFinished( )
+{
+	const XMPP::JT_Register * task = dynamic_cast<const XMPP::JT_Register *>(sender ());
+
+	if ( task && ! task->success ())
+	{
+		KMessageBox::queuedMessageBox ( 0L, KMessageBox::Error,
+			i18n ("An error occured when trying to remove the account:\n%1").arg(task->statusString()),
+			i18n ("Jabber Account Unregistration"));
+		m_removing=false;
+		return;
+	}
+	if(m_removing)  //it may be because this is now the timer.
+		Kopete::AccountManager::self()->removeAccount( this ); //this will delete this
+}
+
+
+
+
+
 #include "jabberaccount.moc"
 
 // vim: set noet ts=4 sts=4 sw=4:
