@@ -23,6 +23,7 @@
 
 #include "jabberaccount.h"
 #include "jabberprotocol.h"
+#include "jabberclient.h"
 #include "dlgjabberregister.h"
 
 dlgJabberRegister::dlgJabberRegister (JabberAccount *account, const XMPP::Jid & jid, QWidget * parent, const char *name):dlgRegister (parent, name)
@@ -71,7 +72,8 @@ void dlgJabberRegister::slotGotForm ()
 
 void dlgJabberRegister::slotSendForm ()
 {
-
+	if(!translator)
+		return;
 	XMPP::JT_Register * task = new XMPP::JT_Register (m_account->client()->rootTask ());
 
 	connect (task, SIGNAL (finished ()), this, SLOT (slotSentForm ()));
