@@ -883,7 +883,7 @@ namespace KPF
   typedef KGenericFactory<PropertiesDialogPlugin, KPropertiesDialog> PropertiesDialogPluginFactory;
 }
 
-K_EXPORT_COMPONENT_FACTORY( kpfpropertiesdialogplugin, 
+K_EXPORT_COMPONENT_FACTORY( kpfpropertiesdialog, 
                             KPF::PropertiesDialogPluginFactory( "kpf" ) )
 
 #include "PropertiesDialogPlugin.moc"
