@@ -2,7 +2,7 @@
  *
  *              kPPP: A pppd Front End for the KDE project
  *
- * $Id: edit.h,v 1.24 2003/03/07 22:06:51 waba Exp $
+ * $Id: edit.h 306105 2004-04-24 18:06:41Z porten $
  *              Copyright (C) 1997 Bernd Johannes Wuebben
  *                      wuebben@math.cornell.edu
  *
@@ -57,6 +57,7 @@ public slots:
   bool save();
   void pppdargsbutton();
   void numbersChanged();
+  void cbtypeChanged(int);
   void selectionChanged(int);
   void addNumber();
   void delNumber();
@@ -72,6 +73,11 @@ private:
   QLabel *auth_l;
   QCheckBox *store_password;
 
+  // callback support
+  QComboBox *cbtype;
+  QLabel *cbtype_l;
+  QLineEdit *cbphone;
+  QLabel *cbphone_l;
   // for the phonenumber selection
   QPushButton *add, *del, *up, *down;
   QListBox *numbers;
