@@ -68,6 +68,7 @@ static const char description[] =
 static const KCmdLineOptions options[] =
 {
    { "c <account_name>", I18N_NOOP("Connect using 'account_name'"), 0 },
+   { "m <modem_name>", I18N_NOOP("Connect using 'modem_name'"), 0 },
    { "k", I18N_NOOP("Terminate an existing connection"), 0 },
    { "q", I18N_NOOP("Quit after end of connection"), 0 },
    { "r <rule_file>", I18N_NOOP("Check syntax of rule_file"), 0 },
@@ -176,8 +177,15 @@ int main( int argc, char **argv ) {
 
   // drop setuid status
   euid = geteuid();
-  setgid(getgid());
+  if (setgid(getgid()) < 0 && errno != EPERM) {
+    perror("setgid() failed");
+    exit(1);
+  }
   setuid(getuid());
+  if (geteuid() != getuid()) {
+    perror("setuid() failed");
+    exit(1);
+  }
 
   //
   // end of setuid-dropping block.
