@@ -45,7 +45,7 @@ typedef KGenericFactory<KcmKRfb, QWidget> KcmKRfbFactory;
 
 // Can't use K_EXPORT_COMPONENT_FACTORY, since insertCatalogue necessary
 extern "C" {
-  void *init_kcm_krfb() {
+  KDE_EXPORT void *init_kcm_krfb() {
     KGlobal::locale()->insertCatalogue("krfb"); // For invitation translations
     return new KcmKRfbFactory("kcm_krfb"); 
   }
@@ -151,6 +151,7 @@ void KcmKRfb::save() {
 		m_configuration.setPreferredPort(m_confWidget->portInput->value());
 	m_configuration.setDisableBackground(m_confWidget->disableBackgroundCB->isChecked());
 	m_configuration.save();
+	kapp->dcopClient()->emitDCOPSignal("KRFB::ConfigChanged", "KRFB_ConfigChanged()", QByteArray());
 	emit changed(false);
 }
 
