@@ -2,7 +2,7 @@
 
  The IO LAG Controller
 
- $$Id: ioLAG.cpp,v 1.10 2001/09/01 14:45:52 mueller Exp $$
+ $$Id: ioLAG.cpp 234524 2003-06-29 15:21:53Z mlaurent $$
 
 **********************************************************************/
 
@@ -29,7 +29,7 @@ KSircIOLAG::~KSircIOLAG()
   killTimers();
 }
 
-void KSircIOLAG::sirc_receive(QString str, bool)
+void KSircIOLAG::sirc_receive(QCString str, bool)
 {
 
   if(str.contains("*L*")){
@@ -37,7 +37,7 @@ void KSircIOLAG::sirc_receive(QString str, bool)
     s1 = str.find("*L* ") + 4;
     s2 = str.length();
     if(s1 < 0 || s2 < 0){
-      kdDebug() << "Lag mesage broken: " << str << endl;
+      kdDebug(5008) << "Lag mesage broken: " << str << endl;
       return;
     }
     QString lag = str.mid(s1, s2 - s1);
@@ -54,7 +54,7 @@ void KSircIOLAG::control_message(int, QString)
 
 void KSircIOLAG::timerEvent ( QTimerEvent * )
 {
-  QString cmd = "/lag\n";
+  QCString cmd = "/lag\n";
   emit outputLine(cmd);
 }
 
