@@ -13,7 +13,7 @@ public:
   KSircIONotify(KSircProcess *_proc);
   virtual ~KSircIONotify();
 
-  virtual void sirc_receive(QString, bool broadcast);
+  virtual void sirc_receive(QCString, bool broadcast);
   virtual void control_message(int, QString);
 
   virtual filterRuleList *defaultRules();
