@@ -2,7 +2,7 @@
 
  IO Controller Object
 
- $$Id: iocontroller.cpp 234524 2003-06-29 15:21:53Z mlaurent $$
+ $$Id: iocontroller.cpp 621565 2007-01-09 03:13:10Z aseigo $$
 
  Main io controller.  Reads and writes strings to sirc.  Input
  received in the following 2 formats:
@@ -237,7 +237,7 @@ void KSircIOController::stdout_read(KProcess *, char *_buffer, int buflen)
 
     if((line.length() > 0) && (line[0] == '~')){
       pos3 = line.find('~', 1);
-      if(pos3 > 0){
+      if(pos3 > 1){
 	name = line.mid(1,pos3-1).lower();
 	name = name.lower();
 	line.remove(0, pos3+1);
@@ -266,13 +266,13 @@ void KSircIOController::stdout_read(KProcess *, char *_buffer, int buflen)
         if(ksopts->autoCreateWin == TRUE && line[0] != '`' && line[1] != '#' && line[1] != '&' && noticeCreate) {
 	    //kdDebug(5008) << "Creating window for: " << qsname << " because of: " << line.data() << endl;
 	    ksircproc->new_toplevel(KSircChannel(ksircproc->serverName(), qsname));
-	    assert(ksircproc->TopList[qsname] != 0x0);
         }
-        else{
+        if (!ksircproc->TopList[qsname]) {
             qsname = "!default";
             if(line[0] == '`')
                 qsname = "!discard";
         }
+        assert(ksircproc->TopList[qsname]);
     }
 
     ksircproc->TopList[qsname]->sirc_receive(line);
