@@ -20,7 +20,7 @@ public:
   const QString port() const      { return m_port; }
   const QString script() const     { return m_script; }
   const QString password() const   { return m_password; }
-  const bool    usessl() const     { return m_ssl; }
+  bool    usessl() const     { return m_ssl; }
 
 private:
   const QString     m_server;
