@@ -27,10 +27,13 @@
 #include <qpixmap.h>
 
 class QTimer;
+class QDragObject;
 
 namespace KSirc
 {
 
+class TextView;
+
 struct StringPtr
 {
     StringPtr() : ptr( 0 ), len( 0 ) {}
@@ -114,7 +117,8 @@ struct ItemProperties
     ItemProperties();
     ItemProperties( const QFont &defaultFont );
     ItemProperties( const ItemProperties &other,
-                    const Token &token );
+                    const Token &token,
+		    TextView *textView );
     ItemProperties( const ItemProperties &rhs );
     ItemProperties &operator=( const ItemProperties &rhs );
 
@@ -123,12 +127,16 @@ struct ItemProperties
     // these three are inherited/merged
     QFont font;
     QColor color;
+    QColor selColor;
     QColor bgColor;
+    QColor bgSelColor;
+    bool reversed;
     // ### todo: inherit these, too
     AttributeMap attributes;
 };
 
 class TextParag;
+class TextLine;
 class SelectionPoint;
 
 class Item
@@ -143,7 +151,9 @@ public:
 
     virtual ~Item();
 
-    virtual void paint( QPainter *painter ) = 0;
+    virtual const char *type() { return "Item"; }
+
+    virtual void paint( QPainter &painter ) = 0;
 
     int width() const;
 
@@ -153,7 +163,7 @@ public:
 
     virtual Item *breakLine( int width );
 
-    virtual LayoutResetStatus resetLayout( Item *originalItem ) = 0;
+    virtual LayoutResetStatus resetLayout() = 0;
 
     virtual int calcSelectionOffset( int x );
 
@@ -165,6 +175,8 @@ public:
 
     int maxSelectionOffset() const;
 
+    void setLine(TextLine *line);
+
     // ###
     virtual StringPtr text() const;
 
@@ -183,6 +195,7 @@ protected:
     virtual void calcExtends() const = 0;
 
     SelectionStatus m_selection;
+    TextLine  *m_line;
     TextParag *m_parag;
     ItemProperties m_props;
 };
@@ -192,11 +205,13 @@ class TextChunk : public Item
 public:
     TextChunk( TextParag *parag, const StringPtr &text, const ItemProperties &props );
 
-    virtual void paint( QPainter *painter );
+    virtual const char *type() { return "TextChunk"; }
+
+    virtual void paint( QPainter &painter );
 
     virtual Item *breakLine( int width );
 
-    virtual LayoutResetStatus resetLayout( Item *originalItem );
+    virtual LayoutResetStatus resetLayout();
 
     virtual int calcSelectionOffset( int x );
 
@@ -208,15 +223,19 @@ protected:
     virtual void calcExtends() const;
 
 private:
-    void paintSelection( QPainter *p );
-    int paintSelection( QPainter *p, int x, const StringPtr &text );
-    int paintText( QPainter *p, int x, const StringPtr &text );
+    StringPtr breakInTheMiddle( int width );
+    Item *hardBreak( const StringPtr &rightHandSide );
+
+    void paintSelection( QPainter &p );
+    int paintSelection( QPainter &p, int x, const StringPtr &text );
+    int paintText( QPainter &p, int x, const StringPtr &text );
 
     void mergeSelection( TextChunk *child, SelectionPoint *selection );
 
     StringPtr m_text;
     uint m_originalTextLength;
     QFontMetrics m_metrics;
+    class TextChunk *m_parent;
 };
 
 class ImageItem : public Item
@@ -224,9 +243,11 @@ class ImageItem : public Item
 public:
     ImageItem( TextParag *parag, const QPixmap &pixmap );
 
-    virtual void paint( QPainter *painter );
+    virtual const char *type() { return "Image"; }
 
-    virtual LayoutResetStatus resetLayout( Item *originalItem );
+    virtual void paint( QPainter &painter );
+
+    virtual LayoutResetStatus resetLayout();
 
 protected:
     virtual void calcExtends() const;
@@ -306,9 +327,9 @@ public:
 
     bool isEmpty() const { return m_items.isEmpty(); }
 
-    void resetLayout( QPtrList<Item> &remainingItems );
+    Item *resetLayout( QPtrList<Item> &remainingItems);
 
-    void paint( QPainter *p, int y );
+    void paint( QPainter &p, int y );
 
     Item *itemAt( int px, SelectionPoint *selectionInfo, 
                   Item::SelectionAccuracy accuracy = Item::SelectExact );
@@ -324,7 +345,6 @@ private:
     int m_maxHeight;
 };
 
-class TextView;
 class SelectionPoint;
 
 class TextParag
@@ -336,7 +356,7 @@ public:
 
     void layout( int width );
 
-    void paint( QPainter *p, int y );
+    void paint( QPainter &p, int y, int maxY );
 
     inline void setLayouted( bool l ) { m_layouted = l; }
     inline bool isLayouted() const { return m_layouted; }
@@ -421,7 +441,29 @@ protected:
 private:
     QPtrListIterator<TextParag> m_paragIt;
 };
- 
+
+class ContentsPaintAlgorithm
+{
+public:
+    ContentsPaintAlgorithm( const QPtrListIterator<TextParag> &paragIt,
+                            QWidget *viewport, QPixmap &paintBuffer,
+                            QPainter &painter, int clipX, int clipY, int clipHeight );
+
+    void paint();
+
+private:
+    int goToFirstVisibleParagraph();
+    int paint( QPainter &bufferedPainter, int currentY );
+    int adjustYAndIterator( int startY, int currentY, int nextY );
+
+    QPtrListIterator<TextParag> m_paragIt;
+    QWidget *m_viewport;
+    QPixmap &m_paintBuffer;
+    QPainter &m_painter;
+    int m_clipX, m_clipY, m_clipHeight;
+    int m_overshoot;
+};
+
 class TextView : public QScrollView
 {
     Q_OBJECT
@@ -447,6 +489,11 @@ public:
 
     QString plainText() const;
 
+    QColor linkColor() const;
+    void setLinkColor( const QColor &linkColor );
+
+    void scrollToBottom( bool force = false );
+
 signals:
     void selectionChanged();
     void pasteReq(const QString&);
@@ -455,18 +502,27 @@ signals:
 public slots:
     void copy();
 
+protected slots:
+    void scrolling(int value);
+
 protected:
     virtual void viewportResizeEvent( QResizeEvent *ev );
     virtual void drawContents( QPainter *p, int cx, int cy, int cw, int ch );
-    virtual void viewportMousePressEvent( QMouseEvent *ev );
-    virtual void viewportMouseMoveEvent( QMouseEvent *ev );
-    virtual void viewportMouseReleaseEvent( QMouseEvent *ev );
+    virtual void contentsMousePressEvent( QMouseEvent *ev );
+    virtual void contentsMouseMoveEvent( QMouseEvent *ev );
+    virtual void contentsMouseReleaseEvent( QMouseEvent *ev );
     virtual void fontChange( const QFont & );
 
+    virtual void startDrag();
+
+    virtual QDragObject *dragObject( const QString &dragURL );
+
 private slots:
     void autoScroll();
 
 private:
+    void emitLinkClickedForMouseEvent( QMouseEvent *ev );
+
     void startAutoScroll();
 
     void stopAutoScroll();
@@ -487,9 +543,12 @@ private:
 
     void clearSelectionInternal();
 
+    void contentsChange(int heightChange, bool force = false);
+
     QPtrList<TextParag> m_parags;
     QPixmap m_paintBuffer;
 
+    SelectionPoint m_selectionMaybeStart;
     SelectionPoint m_selectionStart;
     SelectionPoint m_selectionEnd;
     bool m_selectionEndBeforeStart;
@@ -497,9 +556,20 @@ private:
     QTimer *m_autoScrollTimer;
 
     QString m_selectedText;
+
+    QPoint m_dragStartPos;
+    QString m_dragURL;
+    bool m_mousePressed : 1;
+    bool m_mmbPressed : 1;
+    QColor m_linkColor;
+    QColor m_selectionBackgroundColor;
+
+    int m_height;
+    bool m_inScroll;
+    int m_lastScroll;
 };
 
-}; // namespace KSirc
+} // namespace KSirc
 
 #endif
 /*
