@@ -3,6 +3,7 @@
 #include <qtextcodec.h>
 #include <kcharsets.h>
 #include <kglobal.h>
+#include <kdebug.h>
 #include <assert.h>
 
 KSircMessageReceiver::KSircMessageReceiver( KSircProcess * _proc )
@@ -38,6 +39,8 @@ UnicodeMessageReceiver::UnicodeMessageReceiver( KSircProcess *process )
 void UnicodeMessageReceiver::sirc_receive( QCString str, bool broadcast )
 {
     assert( encoder() );
+    //kdDebug(5008) << "Encoder: " << encoder()->name() << endl;
+    //kdDebug(5008) << "It gives us: " << encoder()->toUnicode( str ).utf8() << endl;
     sirc_receive( encoder()->toUnicode( str ), broadcast );
 }
 
@@ -56,8 +59,9 @@ QString UnicodeMessageReceiver::encoding() const
 
 QTextCodec *UnicodeMessageReceiver::encoder() const
 {
-    if ( m_encoding.isEmpty() )
+    if ( m_encoding.isEmpty() ) {
 	return QTextCodec::codecForLocale();
+    }
 
     if ( !m_encoder ) {
 	const_cast<UnicodeMessageReceiver *>( this )->m_encoder = KGlobal::charsets()->codecForName( m_encoding );
