@@ -10,11 +10,6 @@ class PMenuData;
 #include "pobject.h"
 #include "controller.h"
 
-// Init and setup code
-extern "C" {
-PObject *createWidget(CreateArgs &ca);
-}
-
 /**
  * Little helper class here gives us access to needed info inside
  * QMenuData
