@@ -43,14 +43,7 @@
 #ifdef HAVE_SYS_STAT_H
 #include <sys/stat.h>
 #endif
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#ifdef TIME_WITH_SYS_TIME
 #include <time.h>
-#endif
-#else
-#include <time.h>
-#endif
 #include <sys/wait.h>
 #include <sys/ioctl.h>
 #include <termios.h>
@@ -224,7 +217,7 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
                 {
                     syslog(LOG_DEBUG, "Trying to run '%s' at '%s' as '%s'", extprg,
                            getenv("DISPLAY"), request->r_name );
-                    if (callee) debug("With mention of callee : %s",callee);
+                    if (callee) ktalk_debug("With mention of callee : %s",callee);
                 }
                 /*
                  * point stdout of external program to the pipe
@@ -264,7 +257,7 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
                  * does this work on systems other than BSD&Linux??
                  */
                 if (fcntl(readPipe[0], F_SETFL, O_NONBLOCK)== -1)
-                        debug("Failed to make pipe non-blocking!!");
+                        ktalk_debug("Failed to make pipe non-blocking!!");
 
                 /* Stop this loop when:
                  *  the child exited with a value > 0 AND the pipe is empty
@@ -287,9 +280,9 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
                  * 42 is: failure to start external program.
                  */
                 if (Xannounceok == 1) {
-                    debug("OK - Child process responded");
+                    ktalk_debug("OK - Child process responded");
                 } else
-                    debug("External program failed with exit status: %i", WEXITSTATUS(status));
+                    ktalk_debug("External program failed with exit status: %i", WEXITSTATUS(status));
 
                 // close the pipes: (is this necessary?):
                 close( readPipe[0] );
@@ -310,7 +303,7 @@ int try_Xannounce(NEW_CTL_MSG *request, const char *remote_machine,
         // addition to X announce
         if ((request->r_tty[0]!='\0') && ((int)request->r_tty[3]<(int)'f'))  {
 	  // Not a pseudo terminal (such as an xterm, ...)
-            debug("Doing also text announce on %s",request->r_tty);
+            ktalk_debug("Doing also text announce on %s",request->r_tty);
             print_std_mesg(request, remote_machine, usercfg, 1 /*force no sound*/);
         }
 #endif
@@ -449,13 +442,13 @@ int play_sound(int usercfg)
         because the father will close the file soon !! */
      if ((!usercfg) || (!read_user_config("SoundPlayer",sSoundPlayer,S_CFGLINE)))
          strcpy(sSoundPlayer,Options.soundplayer);
-     debug(sSoundPlayer);
+     ktalk_debug(sSoundPlayer);
      if ((!usercfg) || (!read_user_config("SoundPlayerOpt",sSoundPlayerOpt,S_CFGLINE)))
          strcpy(sSoundPlayerOpt,Options.soundplayeropt);
-     debug(sSoundPlayerOpt);
+     ktalk_debug(sSoundPlayerOpt);
      if ((!usercfg) || (!read_user_config("SoundFile",sSoundFile,S_CFGLINE)))
          strcpy(sSoundFile,Options.soundfile);
-     debug(sSoundFile);
+     ktalk_debug(sSoundFile);
 
      if ((pid = fork())) {
          /* we are the parent, so wait for the child */
@@ -477,7 +470,7 @@ int play_sound(int usercfg)
      else
          returncode = execl(sSoundPlayer,sSoundPlayer/*arg0*/,sSoundFile, (void *)0);
 
-     debug(strerror(errno));
+     ktalk_debug(strerror(errno));
      syslog(LOG_ERR,"ERROR PLAYING SOUND FILE !!!");
      syslog(LOG_ERR, "%s,%s,%s",sSoundPlayer,sSoundFile,sSoundPlayerOpt);
      syslog(LOG_ERR,"RETURN-CODE : %d",returncode);
@@ -497,7 +490,7 @@ int sound_or_beep(int usercfg)
      if ((!usercfg) || (!read_bool_user_config("Sound",&bSound)))
          bSound=Options.sound;
 
-     debug("Sound option in sound_or_beep : %d",bSound);
+     ktalk_debug("Sound option in sound_or_beep : %d",bSound);
 
      if (bSound)
        {
