@@ -194,7 +194,7 @@ struct in_addr TalkConnection::getReplyAddr (struct in_addr destination) {
         client.sin_addr.s_addr != htonl (INADDR_ANY))
     {
       *result = client.sin_addr;
-      debug("Found reply address");
+      ktalk_debug("Found reply address");
       ::close (testsock);
       break;
     }
@@ -202,7 +202,7 @@ struct in_addr TalkConnection::getReplyAddr (struct in_addr destination) {
   }
   if (i == 2) {
     *result = defaultReplyAddr;
-    debug("Couldn't find reply address, using default");
+    ktalk_debug("Couldn't find reply address, using default");
   }
   if (Options.debug_mode) {
       help1 = (unsigned char *) &destination;
@@ -221,7 +221,7 @@ struct in_addr TalkConnection::getReplyAddr (struct in_addr destination) {
  * @return 1 if succeeded to find at least 1 protocol */
 void TalkConnection::findProtocol() {
 
-    debug("Remote protocol unknown. Trying to find it. findProtocol()");
+    ktalk_debug("Remote protocol unknown. Trying to find it. findProtocol()");
     /* The existing ctl_sockt will be used for ntalk */
     int new_socket = ctl_sockt;
     /* We need a new SOCK_DGRAM socket for otalk */
@@ -263,7 +263,7 @@ void TalkConnection::findProtocol() {
 
     for (int retry = 0; (retry < 3) && (protocol==noProtocol); retry ++)
     {
-        debug("Send packets. Retry = %d",retry);
+        ktalk_debug("Send packets. Retry = %d",retry);
         /* Send the messages */
         daemon.sin_port = ntalkDaemonPort;
         int len = sendto (new_socket, (char *) &new_msg, sizeof new_msg, 0,
@@ -289,11 +289,11 @@ void TalkConnection::findProtocol() {
                 // Timeout. Let's exit this loop and retry sending.
                 break;
             }
-            if (nready == 0) debug("select returned 0 ! ");
+            if (nready == 0) ktalk_debug("select returned 0 ! ");
 
             /* Analyze response */
             if (FD_ISSET(old_socket, &read_mask)) {
-                debug("Reading on old_socket");
+                ktalk_debug("Reading on old_socket");
                 cc = ::recv(old_socket, (char *)&old_resp, sizeof (old_resp), 0);
                 if (cc < 0) {
                     if (errno == EINTR)
@@ -303,7 +303,7 @@ void TalkConnection::findProtocol() {
                     if (old_resp.type == LOOK_UP) protocol=talkProtocol; // FOUND
             }
             if (FD_ISSET(new_socket, &read_mask)) {
-                debug("Reading on new_socket");
+                ktalk_debug("Reading on new_socket");
                 cc = ::recv(new_socket, (char *)&new_resp, sizeof (new_resp), 0);
                 if (cc < 0) {
                     if (errno == EINTR)
@@ -323,9 +323,9 @@ void TalkConnection::findProtocol() {
     /* restore old.ctl_addr */
     old_msg.ctl_addr = new_msg.ctl_addr;
     ::close(old_socket);
-    debug("Exiting findProtocol");
-    if (protocol==ntalkProtocol) debug("Exiting findProtocol with protocol = NTALK");
-    else if (protocol==talkProtocol) debug("Exiting findProtocol with protocol = NTALK");
+    ktalk_debug("Exiting findProtocol");
+    if (protocol==ntalkProtocol) ktalk_debug("Exiting findProtocol with protocol = NTALK");
+    else if (protocol==talkProtocol) ktalk_debug("Exiting findProtocol with protocol = NTALK");
     else p_error("FATAL : no protocol found.");
 }
 
@@ -412,7 +412,7 @@ void TalkConnection::ctl_transact(int type, int id_num)
                     continue;
                 p_error("Error waiting for daemon response");
             }
-            if (nready == 0) debug("select returned 0 ! ");
+            if (nready == 0) ktalk_debug("select returned 0 ! ");
         } while (nready == 0);
         /*
          * Keep reading while there are queued messages
@@ -464,14 +464,14 @@ int TalkConnection::look_for_invite(int mandatory)
 	case SUCCESS:
             new_msg.id_num = htonl(id_num);
             old_msg.id_num = htonl(id_num);
-            debug("TalkConnection::look_for_invite : got SUCCESS");
+            ktalk_debug("TalkConnection::look_for_invite : got SUCCESS");
             if (lookup_addr.ta_family != AF_INET)
                 p_error("Response uses invalid network address");
             return (1);
 
 	default:
             /* there wasn't an invitation waiting for us */
-            debug("TalkConnection::look_for_invite : didn't get SUCCESS");
+            ktalk_debug("TalkConnection::look_for_invite : didn't get SUCCESS");
             return (0);
     }
 }
@@ -500,7 +500,7 @@ int TalkConnection::accept()
 /** Connect to another talk client. */
 int TalkConnection::connect()
 {
-    debug("Waiting to connect");
+    ktalk_debug("Waiting to connect");
     do {
         errno = 0;
         if (::connect(sockt, (const sockaddr *)(&lookup_addr), sizeof (struct talk_addr)) != -1)
@@ -513,7 +513,7 @@ int TalkConnection::connect()
          * invitation. (We know there are no newer invitations,
          * the talkd works LIFO.)
          */
-        debug("ECONNREFUSED");
+        ktalk_debug("ECONNREFUSED");
         ctl_transact(DELETE, 0);
         close_sockets();
         return 0;
