@@ -48,7 +48,7 @@ extern char ourhostname[];
 void print_request(const char *cp, const CTL_MSG *mp);
 void print_response(const char *cp, const CTL_RESPONSE *rp);
 void print_broken_packet(const char *pack, size_t len, struct sockaddr_in *);
-void debug(const char *fmt, ...);
+void ktalk_debug(const char *fmt, ...);
 void set_debug(int logging, int badpackets);
 
 /* table.c */
