@@ -40,11 +40,7 @@
 #include <sys/stat.h>
 #include <sys/socket.h>
 #include <sys/un.h>
-#ifdef HAVE_SYS_TIME_H
-#include <sys/time.h>
-#else
 #include <time.h>
-#endif
 #ifdef HAVE_SYS_SELECT_H
 #include <sys/select.h>		// Needed on some systems.
 #endif
