@@ -74,8 +74,9 @@ static const char version[] = "v1.5.2";
 
 int main (int argc, char **argv)
 {
-    KCmdLineArgs::init(argc, argv, "ktalkd", description, version ); // we want to use ktalkd translations
+    KCmdLineArgs::init(argc, argv, "ktalkdlg", description, version );
     KCmdLineArgs::addCmdLineOptions( option );
+    KLocale::setMainCatalogue( "kcmktalkd" );
     KApplication a;
 
     struct timeval clock;
