@@ -38,7 +38,7 @@ IOSlaveSettings::IOSlaveSettings(const QString& config, QWidget *parent)
    QVBoxLayout *layout = new QVBoxLayout(this, KDialog::marginHint(), KDialog::spacingHint());
    layout->setAutoAdd(true);
 
-   QGroupBox* group=new QGroupBox(1, Horizontal, i18n("Show links for the following services"), this);
+   QGroupBox* group=new QGroupBox(1, Horizontal, i18n("Show Links for Following Services"), this);
 
    m_ftpSettings=new PortSettingsBar(i18n("FTP (TCP, port 21): "), group);
    m_httpSettings=new PortSettingsBar(i18n("HTTP (TCP, port 80): "),group);
