@@ -250,12 +250,20 @@ void Loader::slotRetrieverDone(const QByteArray &data, bool success)
 		const char *charData = data.data();
 		int len = data.count();
 
-		while (len && (*charData == ' ' || *charData == '\n' ||
-		               *charData == '\t' || *charData == '\r')) {
+		while (len && QChar(*charData).isSpace()) {
 			--len;
 			++charData;
 		}
 
+		/* It seems that some Microsoft-developed code generates UTF-8 files
+		 * with the three leading unicode characters 0357, 0273, 0277. For
+		 * an example, check http://msdn.microsoft.com/rss.xml
+		 */
+		if (len > 3 && QChar(*charData) == QChar(0357)) {
+			len -= 3;
+			charData += 3;
+		}
+
 		QByteArray tmpData;
 		tmpData.setRawData(charData, len);
 		
