@@ -20,6 +20,7 @@
 
 #include "mainconfig.h"
 #include "wificonfig.h"
+#include "kcmwifi.h"
 
 #include <kcombobox.h>
 #include <klineedit.h>
@@ -27,6 +28,7 @@
 #include <kmessagebox.h>
 #include <kprocio.h>
 #include <kpushbutton.h>
+#include <knuminput.h>
 
 #include <qcheckbox.h>
 #include <qfile.h>
@@ -34,13 +36,20 @@
 MainConfig::MainConfig( QWidget *parent, const char *name )
     : MainConfigBase( parent, name )
 {
+  WifiConfig *config = WifiConfig::instance();
+
+  for (int i=1;i<=config->m_numConfigs;i++) {
+    cmb_presetConfig->insertItem( i18n( "Config %1" ).arg( i ) );  
+  }
+
+
   connect( cb_usePreset, SIGNAL( toggled( bool ) ), SIGNAL( changed() ) );
   connect( cmb_presetConfig, SIGNAL( activated( int ) ), SIGNAL( changed() ) );
-  connect( le_interface, SIGNAL( textChanged( const QString & ) ),
-                         SIGNAL( changed() ) );
+  connect( sb_numConfigs, SIGNAL( valueChanged( int ) ), SIGNAL( changed() ) );
 
-  connect( pb_autodetect, SIGNAL( clicked() ), SLOT( slotAutoDetect() ) );
   connect( pb_activate, SIGNAL( clicked() ), SIGNAL( activateClicked() ) );
+  connect( sb_numConfigs, SIGNAL( valueChanged( int ) ), SLOT( slotChangeNumConfigs( int ) ) );
+
 }
 
 void MainConfig::load()
@@ -49,7 +58,7 @@ void MainConfig::load()
 
   cb_usePreset->setChecked( config->m_usePreset );
   cmb_presetConfig->setCurrentItem( config->m_presetConfig );
-  le_interface->setText( config->m_interface );
+  sb_numConfigs->setValue( config->m_numConfigs );
 }
 
 void MainConfig::save()
@@ -58,73 +67,42 @@ void MainConfig::save()
 
   config->m_usePreset = cb_usePreset->isChecked();
   config->m_presetConfig = cmb_presetConfig->currentItem();
-  config->m_interface = le_interface->text();
+  config->m_numConfigs = sb_numConfigs->value();
 }
 
-void MainConfig::slotAutoDetect()
+void MainConfig::slotChangeNumConfigs( int newnumber )
 {
-  le_interface->setText( QString::null );
 
-  QFile procFile ( "/proc/net/dev" );
+  WifiConfig* config = WifiConfig::instance();
 
-  if ( !procFile.open( IO_ReadOnly ) )
+  if ( config->m_numConfigs < newnumber ) // number of configs raised
   {
-    KMessageBox::sorry( this,
-        i18n( "Unable to autodetect wireless interface." ) );
-    return;
+    int diff = newnumber - config->m_numConfigs;
+    ( (KCMWifi*)parentWidget() )->addConfigTab( diff, false );
+  } 
+  else // number of configs lowered
+  {
+    int diff = config->m_numConfigs - newnumber;
+    ( (KCMWifi*)parentWidget() )->delConfigTab( diff );
+  } 
+}
+
+void MainConfig::registerConfig( int number )
+{
+  if ( number >= KCMWifi::vendorBase ) 
+  {
+    cmb_presetConfig->insertItem( i18n( "Vendor %1" ).arg( number-KCMWifi::vendorBase+1 ) );
   }
-
-  QStringList list;
-  QString line;
-
-  while ( !procFile.atEnd() )
+  else
   {
-    procFile.readLine( line, 9999 );
-    if ( line.find( ":" ) > 0 )
-    {
-      line.truncate ( line.find( ":" ) );
-      list.append( line.stripWhiteSpace() );
-    }
-  }
-
-  procFile.close();
-
-  if ( list.empty() )
-  {
-    KMessageBox::sorry( this,
-        i18n( "Unable to autodetect wireless interface." ) );
-    return;
-  }
-
-  for ( QStringList::Iterator it = list.begin (); it != list.end (); ++it )
-  {
-    if ( ((*it).contains("wifi"))==0 ) { // if the name is wifiX, ignore
-      KProcIO test;
-      test << "iwconfig";
-      test << *it;
-      connect( &test, SIGNAL( readReady( KProcIO * ) ),
-                      SLOT( slotTestInterface( KProcIO * ) ) );
-      test.start ( KProcess::Block );
-    }
-  }
-
-  if ( le_interface->text().isEmpty() )
-  {
-    KMessageBox::sorry( this,
-        i18n( "Unable to autodetect wireless interface." ) );
-    return;
+    WifiConfig* config = WifiConfig::instance();
+    cmb_presetConfig->insertItem( i18n( "Config %1" ).arg( number ), number-1 );
   }
 }
 
-void MainConfig::slotTestInterface( KProcIO *proc )
+void MainConfig::unregisterConfig( int number )
 {
-  QString output;
-  proc->readln( output );
-  if ( output.find ( "no wireless extensions" ) == -1 )
-  {
-    output.truncate( output.find ( " " ) );
-    le_interface->setText( output.stripWhiteSpace() );
-  }
+  cmb_presetConfig->removeItem( number-1 );
 }
 
 #include "mainconfig.moc"
