@@ -38,8 +38,8 @@ main (int argc, char *argv[])
 {
   KAboutData aboutData ("kwifimanager", I18N_NOOP ("KWiFiManager"), VERSION,
 			description, KAboutData::License_GPL,
-			"(c) 2001-04, Stefan Winter");
-  aboutData.addAuthor ("Stefan Winter", 0, "mail@stefan-winter.de");
+			"(c) 2001-05, Stefan Winter");
+  aboutData.addAuthor ("Stefan Winter", I18N_NOOP("Original Author and Maintainer"), "swinter@kde.org");
   aboutData.addCredit ("Helge Deller", I18N_NOOP("Lots of Fixes and Optimizations, added Session Management"),
 			"deller@kde.org");
   KCmdLineArgs::init (argc, argv, &aboutData);
