@@ -93,7 +93,8 @@ WEP_KEY
 NetworkScanning::checkWEP()
 {
   kdDebug() << "In checkWEP()\n";
-  if (networks->text( networks->currentRow() , 3 ) == i18n( "off" ) ) return NONE;
+  if (  (networks->text( networks->currentRow() , 3 ) == i18n( "off" )) ||
+	(networks->text( networks->currentRow() , 3 ) == "" ) ) return NONE;
   if (  (networks->text( networks->currentRow() , 3 ).length()== 5 ) || 
 	(networks->text( networks->currentRow() , 3 ).length()== 13 ) ) return VALID_STRING;
   if (  (networks->text( networks->currentRow() , 3 ).length()== 10 ) ||
